@@ -109,7 +109,7 @@ static int InitSound ( int audio, long channels, unsigned long rate, long nBitsP
 {
   UINT4 tmp;
 
-  fillbytes(&AifcHdr, sizeof(AifcHdr), '\0');
+  memset(&AifcHdr, 0, sizeof(AifcHdr));
   AifcHdr.formChk.ckid	= cpu_to_be32(FOURCC_FORM);
   AifcHdr.formChk.dwSize= cpu_to_be32(expected_bytes +
                         offset_of(AIFCHDR,blocksize)+sizeof(AifcHdr.blocksize)
