@@ -216,8 +216,7 @@ unsigned int get_current_track()
 	return current_track;
 }
 
-static void RestrictPlaybackRate( newrate )
-	long newrate;
+static void RestrictPlaybackRate(long newrate)
 {
        global.playback_rate = newrate;
 
@@ -229,14 +228,12 @@ static void RestrictPlaybackRate( newrate )
 }
 
 
-long SamplesNeeded( amount, undersampling_val)
-	long amount;
-	long undersampling_val;
+long SamplesNeeded(long amount, long undersampling_val)
 {
-  long retval = ((undersampling_val * 2 + Halved)*amount)/2;
-  if (Halved && (*nSamplesToDo & 1))
-    retval += 2;
-  return retval;
+	long retval = ((undersampling_val * 2 + Halved)*amount)/2;
+	if (Halved && (*nSamplesToDo & 1))
+		retval += 2;
+	return retval;
 }
 
 static int argc2;
@@ -264,8 +261,7 @@ static char *get_next_name ()
 static char *cut_extension __PR(( char * fname ));
 
 static char
-*cut_extension (fname)
-	char *fname;
+*cut_extension (char *fname)
 {
 	char *pp;
 
@@ -280,35 +276,32 @@ static char
 }
 
 #ifdef INFOFILES
-static void output_indices(fp, p, trackstart)
-	FILE *fp;
-	index_list *p;
-	unsigned trackstart;
+static void output_indices(FILE *fp, index_list *p, unsigned trackstart)
 {
-  int ci;
+	int ci;
 
-  fprintf(fp, "Index=\t\t");
+	fprintf(fp, "Index=\t\t");
 
-  if (p == NULL) {
-    fprintf(fp, "0\n");
-    return;
-  }
+	if (p == NULL) {
+		fprintf(fp, "0\n");
+		return;
+	}
 
-  for (ci = 1; p != NULL; ci++, p = p->next) {
-    int frameoff = p->frameoffset;
+	for (ci = 1; p != NULL; ci++, p = p->next) {
+		int frameoff = p->frameoffset;
 
-    if (p->next == NULL)
-	 fputs("\nIndex0=\t\t", fp);
+		if (p->next == NULL)
+			fputs("\nIndex0=\t\t", fp);
 #if 0
-    else if ( ci > 8 && (ci % 8) == 1)
-	 fputs("\nIndex =\t\t", fp);
+		else if ( ci > 8 && (ci % 8) == 1)
+			fputs("\nIndex =\t\t", fp);
 #endif
-    if (frameoff != -1)
-         fprintf(fp, "%d ", frameoff - trackstart);
-    else
-         fprintf(fp, "-1 ");
-  }
-  fputs("\n", fp);
+		if (frameoff != -1)
+			fprintf(fp, "%d ", frameoff - trackstart);
+		else
+			fprintf(fp, "-1 ");
+	}
+	fputs("\n", fp);
 }
 
 /*
@@ -317,53 +310,45 @@ static void output_indices(fp, p, trackstart)
  *
  * uglyfied for Joerg Schillings ultra dumb line parser
  */
-static int write_info_file(fname_baseval, track, SamplesDone, numbered)
-	char *fname_baseval;
-	unsigned int track;
-	unsigned long int SamplesDone;
-	int numbered;
+static int write_info_file(char *fname_baseval, unsigned int track, unsigned long SamplesDone, int numbered)
 {
-  FILE *info_fp;
-  char fname[200];
-  char datetime[30];
-  time_t utc_time;
-  struct tm *tmptr;
+	FILE *info_fp;
+	char fname[200];
+	char datetime[30];
+	time_t utc_time;
+	struct tm *tmptr;
 
-  /* write info file */
-  if (!strcmp(fname_baseval,"-")) return 0;
+	/* write info file */
+	if (!strcmp(fname_baseval,"-")) return 0;
 
-  strncpy(fname, fname_baseval, sizeof(fname) -1);
-  fname[sizeof(fname) -1] = 0;
-  if (numbered)
-    sprintf(cut_extension(fname), "_%02u.inf", track);
-  else
-    strcpy(cut_extension(fname), ".inf");
+	strncpy(fname, fname_baseval, sizeof(fname) -1);
+	fname[sizeof(fname) -1] = 0;
+	if (numbered)
+		sprintf(cut_extension(fname), "_%02u.inf", track);
+	else
+		strcpy(cut_extension(fname), ".inf");
 
-  info_fp = fopen (fname, "w");
-  if (!info_fp)
-    return -1;
+	info_fp = fopen (fname, "w");
+	if (!info_fp)
+		return -1;
 
 #if 0
 #ifdef MD5_SIGNATURES
-  if (global.md5blocksize)
-    MD5Final (global.MD5_result, &global.context);
+	if (global.md5blocksize)
+		MD5Final (global.MD5_result, &global.context);
 #endif
 #endif
 
-  utc_time = time(NULL);
-  tmptr = localtime(&utc_time);
-  if (tmptr) {
-    strftime(datetime, sizeof(datetime), "%x %X", tmptr);
-  } else {
-    strncpy(datetime, "unknown", sizeof(datetime));
-  }
-  fprintf(info_fp, "#created by cdda2wav %s %s\n#\n", VERSION
-	  , datetime
-	  );
-  fprintf(info_fp,
-"CDINDEX_DISCID=\t'%s'\n" , global.cdindex_id);
-  fprintf(info_fp,
-"CDDB_DISCID=\t0x%08lx\nMCN=\t\t%s\nISRC=\t\t%15.15s\n#\nPerformer=\t'%s'\nAlbumtitle=\t'%s'\n"
+	utc_time = time(NULL);
+	tmptr = localtime(&utc_time);
+	if (tmptr) {
+		strftime(datetime, sizeof(datetime), "%x %X", tmptr);
+	} else {
+		strncpy(datetime, "unknown", sizeof(datetime));
+	}
+	fprintf(info_fp, "#created by cdda2wav %s %s\n#\n", VERSION, datetime);
+	fprintf(info_fp, "CDINDEX_DISCID=\t'%s'\n" , global.cdindex_id);
+	fprintf(info_fp, "CDDB_DISCID=\t0x%08lx\nMCN=\t\t%s\nISRC=\t\t%15.15s\n#\nPerformer=\t'%s'\nAlbumtitle=\t'%s'\n"
 	  , (unsigned long) global.cddb_id
 	  , Get_MCN()
 	  , Get_ISRC(track)
@@ -371,35 +356,18 @@ static int write_info_file(fname_baseval, track, SamplesDone, numbered)
 		(global.creator != NULL ? global.creator : (const unsigned char *)"")
 	  , global.disctitle != NULL ? global.disctitle : (const unsigned char *)""
 	  );
-  fprintf(info_fp,
-	  "Tracktitle=\t'%s'\n"
-	  , global.tracktitle[track] ? global.tracktitle[track] : (const unsigned char *)""
+	fprintf(info_fp, "Tracktitle=\t'%s'\n",
+			global.tracktitle[track] ? global.tracktitle[track] : (const unsigned char *)""
 	  );
-  fprintf(info_fp, "Tracknumber=\t%u\n"
-	  , track
-	  );
-  fprintf(info_fp, 
-	  "Trackstart=\t%ld\n"
-	  , Get_AudioStartSector(track)
-	  );
-  fprintf(info_fp, 
-	  "# track length in sectors (1/75 seconds each), rest samples\nTracklength=\t%ld, %d\n"
-	  , SamplesDone/588L,(int)(SamplesDone%588));
-  fprintf(info_fp, 
-	  "Pre-emphasis=\t%s\n"
-	  , Get_Preemphasis(track) && (global.deemphasize == 0) ? "yes" : "no");
-  fprintf(info_fp, 
-	  "Channels=\t%d\n"
-	  , Get_Channels(track) ? 4 : global.channels == 2 ? 2 : 1);
-  fprintf(info_fp, 
-	  "Copy_permitted=\t%s\n"
-	  , Get_Copyright(track) ? "yes" : "no");
-  fprintf(info_fp, 
-	  "Endianess=\t%s\n"
-	  , global.need_big_endian ? "big" : "little"
-	  );
-  fprintf(info_fp, "# index list\n");
-  output_indices(info_fp, global.trackindexlist[track],
+	fprintf(info_fp, "Tracknumber=\t%u\n", track);
+	fprintf(info_fp, "Trackstart=\t%ld\n", Get_AudioStartSector(track));
+	fprintf(info_fp,  "# track length in sectors (1/75 seconds each), rest samples\nTracklength=\t%ld, %d\n", SamplesDone/588L,(int)(SamplesDone%588));
+	fprintf(info_fp, "Pre-emphasis=\t%s\n", Get_Preemphasis(track) && (global.deemphasize == 0) ? "yes" : "no");
+	fprintf(info_fp, "Channels=\t%d\n", Get_Channels(track) ? 4 : global.channels == 2 ? 2 : 1);
+	fprintf(info_fp, "Copy_permitted=\t%s\n", Get_Copyright(track) ? "yes" : "no");
+	fprintf(info_fp, "Endianess=\t%s\n", global.need_big_endian ? "big" : "little");
+	fprintf(info_fp, "# index list\n");
+	output_indices(info_fp, global.trackindexlist[track],
 		 Get_AudioStartSector(track));
 #if 0
 /* MD5 checksums in info files are currently broken.
@@ -407,7 +375,7 @@ static int write_info_file(fname_baseval, track, SamplesDone, numbered)
  *  before the recording starts, so there is no checksum at that point.
  */
 #ifdef MD5_SIGNATURES
-  fprintf(info_fp, 
+	fprintf(info_fp, 
 	  "#(blocksize) checksum\nMD-5=\t\t(%d) %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x\n"
 	  , global.md5blocksize
 	  , global.MD5_result[0]
@@ -428,15 +396,12 @@ static int write_info_file(fname_baseval, track, SamplesDone, numbered)
 	  , global.MD5_result[15]);
 #endif
 #endif
-  fclose(info_fp);
-  return 0;
+	fclose(info_fp);
+	return 0;
 }
 #endif
 
-static void CloseAudio(channels_val, nSamples, audio_out)
-	int channels_val;
-	unsigned long nSamples;
-	struct soundfile *audio_out;
+static void CloseAudio(int channels_val, unsigned long nSamples, struct soundfile *audio_out)
 {
       /* define length */
       audio_out->ExitSound( global.audio, (nSamples-global.SkippedSamples)*global.OutSampleSize*channels_val );
@@ -555,21 +520,11 @@ fprintf(stderr, "\nW Parent child death, state:%d\n", chld_return_status);
 
 
 /* report a usage error and exit */
-#ifdef  PROTOTYPES
 static void usage2 (const char *szMessage, ...)
-#else
-static void usage2 (szMessage, va_alist)
-	const char *szMessage;
-	va_dcl
-#endif
 {
   va_list marker;
 
-#ifdef  PROTOTYPES
   va_start(marker, szMessage);
-#else
-  va_start(marker);
-#endif
 
   error("%r", szMessage, marker);
 
@@ -581,21 +536,11 @@ static void usage2 (szMessage, va_alist)
 
 
 /* report a fatal error, clean up and exit */
-#ifdef  PROTOTYPES
 void FatalError (const char *szMessage, ...)
-#else
-void FatalError (szMessage, va_alist)
-	const char *szMessage;
-	va_dcl
-#endif
 {
   va_list marker;
 
-#ifdef  PROTOTYPES
   va_start(marker, szMessage);
-#else
-  va_start(marker);
-#endif
 
   error("%r", szMessage, marker);
 
@@ -619,13 +564,7 @@ void FatalError (szMessage, va_alist)
  * is known). So hitting the interrupt key leaves an intact
  * file.
  */
-static void OpenAudio (fname, rate, nBitsPerSample, channels_val, expected_bytes, audio_out)
-	char *fname;
-	double rate;
-	long nBitsPerSample;
-	long channels_val;
-	unsigned long expected_bytes;
-	struct soundfile * audio_out;
+static void OpenAudio (char *fname, double rate, long nBitsPerSample, long channels_val, unsigned long expected_bytes, struct soundfile *audio_out)
 {
   if (global.audio == -1) {
 
@@ -657,8 +596,7 @@ static void OpenAudio (fname, rate, nBitsPerSample, channels_val, expected_bytes
 
 static int RealEnd __PR((SCSI *scgp));
 
-static int RealEnd(scgp)
-	SCSI	*scgp;
+static int RealEnd(SCSI *scgp)
 {
 	if (scg_cmd_err(scgp) != 0) {
 		int c,k,q;
@@ -681,24 +619,21 @@ static int RealEnd(scgp)
 	return 0;
 }
 
-static void set_offset(p, offset)
-	myringbuff *p;
-	int offset;
+static void set_offset(myringbuff *p, int offset)
 {
 #ifdef DEBUG_SHM
-  fprintf(stderr, "Write offset %d at %p\n", offset, &p->offset);
+	fprintf(stderr, "Write offset %d at %p\n", offset, &p->offset);
 #endif
-  p->offset = offset;
+	p->offset = offset;
 }
 
 
-static int get_offset(p)
-myringbuff *p;
+static int get_offset(myringbuff *p)
 {
 #ifdef DEBUG_SHM
-  fprintf(stderr, "Read offset %d from %p\n", p->offset, &p->offset);
+	fprintf(stderr, "Read offset %d from %p\n", p->offset, &p->offset);
 #endif
-  return p->offset;
+	return p->offset;
 }
 
 
@@ -918,9 +853,7 @@ static void init_globals()
 #if !defined (HAVE_STRCASECMP) || (HAVE_STRCASECMP != 1)
 #include <ctype.h>
 static int strcasecmp __PR(( const char *s1, const char *s2 ));
-static int strcasecmp(s1, s2)
-	const char *s1;
-	const char *s2;
+static int strcasecmp(const char *s1, const char *s2)
 {
   if (s1 && s2) {
     while (*s1 && *s2 && (tolower(*s1) - tolower(*s2) == 0)) {
@@ -936,8 +869,7 @@ static int strcasecmp(s1, s2)
 }
 #endif
 
-static int is_fifo(filename)
-	char * filename;
+static int is_fifo(char *filename)
 {
 #if	defined S_ISFIFO
   struct stat statstruct;
@@ -961,10 +893,7 @@ static int is_fifo(filename)
 
 #if !defined (HAVE_STRTOUL) || (HAVE_STRTOUL != 1)
 static unsigned int strtoul __PR(( const char *s1, char **s2, int base ));
-static unsigned int strtoul(s1, s2, base)
-        const char *s1;
-        char **s2;
-	int base;
+static unsigned int strtoul(const char *s1, char **s2, int base)
 {
 	long retval;
 
@@ -1105,8 +1034,7 @@ switch_to_realtime_priority()
 /* wrapper for signal handler exit needed for Mac-OS-X */
 static void exit_wrapper __PR((int status));
 
-static void exit_wrapper(status)
-	int status;
+static void exit_wrapper(int status)
 {
 	exit(status);
 }
@@ -1115,8 +1043,7 @@ static void exit_wrapper(status)
 static void set_nonforked __PR((int status));
 
 /* ARGSUSED */
-static void set_nonforked(status)
-	int status;
+static void set_nonforked(int status)
 {
 	global.parent_died = 1;
 #if defined DEBUG_CLEANUP
@@ -1163,9 +1090,7 @@ static unsigned long calc_SectorBurst()
 #define	PERCENTAGE_PER_TRACK
 
 static int do_read __PR((myringbuff *p, unsigned *total_unsuccessful_retries));
-static int do_read (p, total_unsuccessful_retries)
-	myringbuff	*p;
-	unsigned	*total_unsuccessful_retries;
+static int do_read (myringbuff *p, unsigned *total_unsuccessful_retries)
 {
       unsigned char *newbuf;
       int offset;
@@ -1335,8 +1260,7 @@ static int do_read (p, total_unsuccessful_retries)
 
 
 static unsigned long do_write __PR((myringbuff *p));
-static unsigned long do_write (p)
-	myringbuff	*p;
+static unsigned long do_write (myringbuff *p)
 {
       int current_offset;
       unsigned int InSamples;
@@ -1555,9 +1479,7 @@ nonforked_loop()
 #endif
 
 /* and finally: the MAIN program */
-int main( argc, argv )
-	int argc;
-	char *argv [];
+int main( int argc, char **argv )
 {
   long lSector_p1;
   long sector_offset = 0;
@@ -2039,7 +1961,7 @@ fprintf(stderr, "MD5 signatures are currently broken! Sorry\n");
 
 #if	defined (HAVE_FORK_AND_SHAREDMEM)
 #if	defined(HAVE_SMMAP) || defined(HAVE_USGSHM) || defined(HAVE_DOSALLOCSHAREDMEM)
-    he_fill_buffer = request_shm_sem(global.shmsize, (unsigned char **)&he_fill_buffer);
+    he_fill_buffer = (myringbuff**)request_shm_sem(global.shmsize, (unsigned char **)&he_fill_buffer);
     if (he_fill_buffer == NULL) {
 #else /* have shared memory */
     if (1) {
