@@ -42,6 +42,3 @@
 #else
 #undef FIFO
 #endif
-#if	!defined	HAVE_MEMMOVE
-#define	memmove(dst, src, size)	movebytes((src), (dst), (size))
-#endif
