@@ -95,11 +95,7 @@ int memcmp(const void * a, const void * b, size_t c)
 #endif
 
 static const unsigned char *
-my_symmemmem (HAYSTACK, HAYSTACK_LEN, NEEDLE, NEEDLE_LEN)
-	const unsigned char * HAYSTACK;
-	const size_t HAYSTACK_LEN;
-	const unsigned char * const NEEDLE;
-	const size_t NEEDLE_LEN;
+my_symmemmem (const unsigned char *HAYSTACK, const size_t HAYSTACK_LEN, const unsigned char * const NEEDLE, const size_t NEEDLE_LEN)
 {
   const unsigned char * const UPPER_LIMIT = HAYSTACK + HAYSTACK_LEN - NEEDLE_LEN - 1;
   const unsigned char * HAYSTACK2 = HAYSTACK-1;
@@ -126,11 +122,7 @@ my_symmemmem (HAYSTACK, HAYSTACK_LEN, NEEDLE, NEEDLE_LEN)
 }
 
 static const unsigned char *
-my_memmem (HAYSTACK, HAYSTACK_LEN, NEEDLE, NEEDLE_LEN)
-	const unsigned char * HAYSTACK;
-	const size_t HAYSTACK_LEN;
-	const unsigned char * const NEEDLE;
-	const size_t NEEDLE_LEN;
+my_memmem (const unsigned char *HAYSTACK, const size_t HAYSTACK_LEN, const unsigned char * const NEEDLE, const size_t NEEDLE_LEN)
 {
   const unsigned char * const UPPER_LIMIT = HAYSTACK + HAYSTACK_LEN - NEEDLE_LEN;
 
@@ -152,11 +144,7 @@ my_memmem (HAYSTACK, HAYSTACK_LEN, NEEDLE, NEEDLE_LEN)
 }
 
 static const unsigned char *
-my_memrmem (HAYSTACK, HAYSTACK_LEN, NEEDLE, NEEDLE_LEN)
-	const unsigned char * HAYSTACK;
-	const size_t HAYSTACK_LEN;
-	const unsigned char * const NEEDLE;
-	const size_t NEEDLE_LEN;
+my_memrmem (const unsigned char *HAYSTACK, const size_t HAYSTACK_LEN, const unsigned char * const NEEDLE, const size_t NEEDLE_LEN)
 {
   const unsigned char * const LOWER_LIMIT = HAYSTACK - (HAYSTACK_LEN - 1);
 
@@ -179,8 +167,7 @@ my_memrmem (HAYSTACK, HAYSTACK_LEN, NEEDLE, NEEDLE_LEN)
 
 /* find continuation in new buffer */
 static const unsigned char *
-sync_buffers(newbuf)
-	const unsigned char * const newbuf;
+sync_buffers(const unsigned char * const newbuf)
 {
     const unsigned char *retval = newbuf;
 
@@ -259,10 +246,7 @@ sync_buffers(newbuf)
 /* quadratic interpolation
  * p1, p3 span the interval 0 - 2. give interpolated value for 1/2 */
 static long int 
-interpolate( p1, p2, p3)
-	long int p1;
-	long int p2;
-	long int p3;
+interpolate(long int p1, long int p2, long int p3)
 {
   return (3L*p1 + 6L*p2 - p3)/8L;
 }
@@ -273,10 +257,7 @@ static unsigned char *pDst;	/* start of output buffer */
  * Write the filtered sample into the output buffer.
  */
 static void 
-emit_sample( lsumval, rsumval, channels )
-	long lsumval;
-	long rsumval;
-	long channels;
+emit_sample(long lsumval, long rsumval, long channels)
 {
     if (global.findminmax) {
        if (rsumval > global.maxamp[0]) global.maxamp[0] = rsumval;
@@ -356,9 +337,7 @@ emit_sample( lsumval, rsumval, channels )
     }
 }
 
-static void change_endianness(pSam, Samples)
-	UINT4 *pSam;
-	unsigned int Samples;
+static void change_endianness(UINT4 *pSam, unsigned int Samples)
 {
   UINT4 *pend = (pSam + Samples);
 
@@ -419,9 +398,7 @@ error type unsigned long is too small
 #endif
 }
 
-static void swap_channels(pSam, Samples)
-	UINT4 *pSam;
-	unsigned int Samples;
+static void swap_channels(UINT4 *pSam, unsigned int Samples)
 {
   UINT4 *pend = (pSam + Samples);
 
@@ -484,11 +461,7 @@ error type unsigned long is too small
 
 #ifdef	ECHO_TO_SOUNDCARD
 static long ReSampleBuffer			__PR((unsigned char *p, unsigned char *newp, long samples, int samplesize));
-static long ReSampleBuffer( p, newp, samples, samplesize)
-	unsigned char *p;
-	unsigned char *newp;
-	long samples;
-	int samplesize;
+static long ReSampleBuffer( unsigned char *p, unsigned char *newp, long samples, int samplesize)
 {
 	double idx=0.0;
 	UINT4  di=0,si=0;
@@ -506,10 +479,7 @@ static long ReSampleBuffer( p, newp, samples, samplesize)
 }
 #endif
 
-static int guess_endianess(p, p2, SamplesToDo)
-	UINT4 *p;
-	Int16_t *p2;
-	unsigned SamplesToDo;
+static int guess_endianess(UINT4 *p, Int16_t *p2, unsigned SamplesToDo)
 {
     /* analyse samples */
     int vote_for_little = 0;
@@ -560,10 +530,7 @@ static int guess_endianess(p, p2, SamplesToDo)
 
 int jitterShift = 0; 
 
-unsigned char *synchronize(p, SamplesToDo, TotSamplesDone)
-	UINT4 *p;
-	unsigned SamplesToDo;
-	unsigned TotSamplesDone;
+unsigned char *synchronize(UINT4 *p, unsigned SamplesToDo, unsigned TotSamplesDone)
 {
   static int jitter = 0;
   char *pSrc;                   /* start of cdrom buffer */
@@ -646,10 +613,7 @@ unsigned char *synchronize(p, SamplesToDo, TotSamplesDone)
  * 
  */
 long 
-SaveBuffer (p, SamplesToDo, TotSamplesDone)
-	UINT4 *p;
-	unsigned long SamplesToDo;
-	unsigned long *TotSamplesDone;
+SaveBuffer (UINT4 *p, unsigned long SamplesToDo, unsigned long *TotSamplesDone)
 {
   UINT4 *pSrc;                   /* start of cdrom buffer */
   UINT4 *pSrcStop;               /* end of cdrom buffer */
