@@ -63,7 +63,7 @@ int heiko_mmc(SCSI *scgp)
         struct  cd_mode_page_2A *mp;
 	int retval;
 
-        fillbytes((caddr_t)mode, sizeof(mode), '\0');
+        memset((caddr_t)mode, 0, sizeof(mode));
 
         was_atapi = allow_atapi(scgp, 1);
         scgp->silent++;
@@ -139,7 +139,7 @@ int set_sectorsize (SCSI *scgp, unsigned int secsize)
 
   /* prepare to read cds in the previous mode */
 
-  fillbytes((caddr_t)mode, sizeof(mode), '\0');
+  memset((caddr_t)mode, 0, sizeof(mode));
   mode[ 3] = 8; 	       /* Block Descriptor Length */
   mode[ 4] = orgmode4; 	       /* normal density */
   mode[10] =  secsize >> 8;   /* block length "msb" */
@@ -215,7 +215,7 @@ void ReadTocTextSCSIMMC ( SCSI *scgp )
      len lsb, control */
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)bufferTOC;
         scmd->size = 4;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -244,7 +244,7 @@ void ReadTocTextSCSIMMC ( SCSI *scgp )
     datalength  = (p[0] << 8) | (p[1]);
     if (datalength <= 2) return;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)bufferTOC;
         scmd->size = 2+datalength;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -275,7 +275,7 @@ void ReadTocTextSCSIMMC ( SCSI *scgp )
 	fp = fopen("PearlJam.cdtext", "rb");
 	/*fp = fopen("celine.cdtext", "rb");*/
 	if (fp == NULL) { perror(""); return; }
-	fillbytes(bufferTOC, CD_FRAMESIZE, '\0');
+	memset(bufferTOC, 0, CD_FRAMESIZE);
 	read_ = fread(bufferTOC, 1, CD_FRAMESIZE, fp );
 fprintf(stderr, "read %d bytes. sizeof(bufferTOC)=%u\n", read_, CD_FRAMESIZE);
         datalength  = (bufferTOC[0] << 8) | (bufferTOC[1]);
@@ -292,7 +292,7 @@ static unsigned ReadFullTOCSony ( SCSI *scgp )
 	register struct	scg_cmd	*scmd = scgp->scmd;
 	unsigned tracks = 99;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)bufferTOC;
         scmd->size = 4 + (3 + tracks + 6) * 11;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -515,7 +515,7 @@ static unsigned ReadFullTOCMMC ( SCSI *scgp )
 	register struct	scg_cmd	*scmd = scgp->scmd;
 	unsigned tracks = 99;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)bufferTOC;
         scmd->size = 4 + (tracks + 8) * 11;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -711,7 +711,7 @@ unsigned ReadTocSCSI ( SCSI *scgp )
        len lsb, flags */
     register struct	scg_cmd	*scmd = scgp->scmd;
 
-    fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+    memset((caddr_t)scmd, 0, sizeof(*scmd));
     scmd->addr = (caddr_t)bufferTOC;
     scmd->size = 4;
     scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -736,7 +736,7 @@ unsigned ReadTocSCSI ( SCSI *scgp )
     
     
     memset(bufferTOCMSF, 0, sizeof(bufferTOCMSF));
-    fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+    memset((caddr_t)scmd, 0, sizeof(*scmd));
     scmd->addr = (caddr_t)bufferTOCMSF;
     scmd->size = 4 + tracks * 8;
     scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -760,7 +760,7 @@ unsigned ReadTocSCSI ( SCSI *scgp )
     }
 
     /* LBA format for cd burners like Philips CD-522 */
-    fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+    memset((caddr_t)scmd, 0, sizeof(*scmd));
     scmd->addr = (caddr_t)bufferTOC;
     scmd->size = 4 + tracks * 8;
     scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -793,7 +793,7 @@ int ReadStandard (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstVa
      transfer len msb, transfer len lsb, block addressing mode */
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)p;
         scmd->size = SectorBurstVal*CD_FRAMESIZE_RAW;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -822,7 +822,7 @@ int ReadCdda10 (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstVal)
      transfer len msb, transfer len lsb, block addressing mode */
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)p;
         scmd->size = SectorBurstVal*CD_FRAMESIZE_RAW;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -850,7 +850,7 @@ int ReadCdda12 (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstVal
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)p;
         scmd->size = SectorBurstVal*CD_FRAMESIZE_RAW;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -883,7 +883,7 @@ int ReadCdda12Matsushita (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned Secto
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-        fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+        memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)p;
         scmd->size = SectorBurstVal*CD_FRAMESIZE_RAW;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -912,7 +912,7 @@ int ReadCddaMMC12 (SCSI *scgp, UINT4 *p, unsigned lSector, unsigned SectorBurstV
 	register struct	scg_cmd	*scmd;
 	scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)p;
         scmd->size = SectorBurstVal*CD_FRAMESIZE_RAW;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -962,7 +962,7 @@ static subq_chnl *ReadSubQFallback (SCSI *scgp, unsigned char sq_format, unsigne
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)SubQbuffer;
         scmd->size = 24;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -1019,7 +1019,7 @@ subq_chnl *ReadSubQSCSI (SCSI *scgp, unsigned char sq_format, unsigned char trac
                 return NULL;
         }
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->addr = (caddr_t)SubQbuffer;
         scmd->size = resp_size;
         scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -1053,7 +1053,7 @@ void SpeedSelectSCSIToshiba (SCSI *scgp, unsigned speed)
   unsigned char *page = mode + 4;
   int retval;
 
-  fillbytes((caddr_t)mode, sizeof(mode), '\0');
+  memset((caddr_t)mode, 0, sizeof(mode));
   /* the first 4 mode bytes are zero. */
   page[0] = 0x20;
   page[1] = 1;
@@ -1075,14 +1075,14 @@ void SpeedSelectSCSINEC (SCSI *scgp, unsigned speed)
   int retval;
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-  fillbytes((caddr_t)mode, sizeof(mode), '\0');
+  memset((caddr_t)mode, 0, sizeof(mode));
   /* the first 4 mode bytes are zero. */
   page [0] = 0x0f; /* page code */
   page [1] = 6;    /* parameter length */
   /* bit 5 == 1 for single speed, otherwise double speed */
   page [2] = speed == 1 ? 1 << 5 : 0;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
   scmd->addr = (caddr_t)mode;
   scmd->size = 12;
   scmd->flags = SCG_DISRE_ENA;
@@ -1110,7 +1110,7 @@ void SpeedSelectSCSIPhilipsCDD2600 (SCSI *scgp, unsigned speed)
   unsigned char *page = mode + 4;
   int retval;
 
-  fillbytes((caddr_t)mode, sizeof(mode), '\0');
+  memset((caddr_t)mode, 0, sizeof(mode));
   /* the first 4 mode bytes are zero. */
   page[0] = 0x23;
   page[1] = 6;
@@ -1129,7 +1129,7 @@ void SpeedSelectSCSISony (SCSI *scgp, unsigned speed)
   unsigned char *page = mode + 4;
   int retval;
 
-  fillbytes((caddr_t)mode, sizeof(mode), '\0');
+  memset((caddr_t)mode, 0, sizeof(mode));
   /* the first 4 mode bytes are zero. */
   page[0] = 0x31;
   page[1] = 2;
@@ -1149,7 +1149,7 @@ void SpeedSelectSCSIYamaha (SCSI *scgp, unsigned speed)
   unsigned char *page = mode + 4;
   int retval;
 
-  fillbytes((caddr_t)mode, sizeof(mode), '\0');
+  memset((caddr_t)mode, 0, sizeof(mode));
   /* the first 4 mode bytes are zero. */
   page[0] = 0x31;
   page[1] = 2;
@@ -1171,7 +1171,7 @@ void SpeedSelectSCSIMMC (SCSI *scgp, unsigned speed)
    } else {
       spd = (1764 * speed) / 10;
    }
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
         scmd->flags = SCG_DISRE_ENA;
         scmd->cdb_len = SC_G5_CDBLEN;
         scmd->sense_len = CCS_SENSE_LEN;
@@ -1212,8 +1212,8 @@ unsigned char *Inquiry ( SCSI *scgp )
     }
   }
 
-  fillbytes(Inqbuffer, 36, '\0');
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+  memset(Inqbuffer, 0, 36);
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
   scmd->addr = (caddr_t)Inqbuffer;
   scmd->size = 36;
   scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -1255,7 +1255,7 @@ int TestForMedium ( SCSI *scgp )
   }
 
   /* request READY status */
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
   scmd->addr = (caddr_t)0;
   scmd->size = 0;
   scmd->flags = SCG_DISRE_ENA | (1 ? SCG_SILENT:0);
@@ -1290,7 +1290,7 @@ int StopPlaySCSI ( SCSI *scgp )
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
 	scmd->addr = NULL;
 	scmd->size = 0;
 	scmd->flags = SCG_DISRE_ENA;
@@ -1311,7 +1311,7 @@ int Play_atSCSI ( SCSI *scgp, unsigned int from_sector, unsigned int sectors)
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
   scmd->addr = NULL;
   scmd->size = 0;
   scmd->flags = SCG_DISRE_ENA;
