@@ -98,11 +98,7 @@ static unsigned char g_track=0xff, g_index=0xff;	/* current track, index */
 
 /* Conversion function: from logical block adresses  to minute,second,frame
  */
-int lba_2_msf (lba, m, s, f)
-	long	lba;
-	int	*m;
-	int	*s;
-	int	*f;
+int lba_2_msf (long lba, int *m, int *s, int *f)
 {
 #ifdef  __follow_redbook__
 	if (lba >= -150 && lba < 405000) {      /* lba <= 404849 */
@@ -125,8 +121,7 @@ int lba_2_msf (lba, m, s, f)
 }
 
 /* print the track currently read */
-static void UpdateTrackData (p_num)
-	int	p_num;
+static void UpdateTrackData (int p_num)
 {
   if (global.quiet == 0) { 
     fprintf (stderr, "\ntrack: %.2d, ", p_num); fflush(stderr);
@@ -136,8 +131,7 @@ static void UpdateTrackData (p_num)
 
 
 /* print the index currently read */
-static void UpdateIndexData (p_num)
-	int p_num;
+static void UpdateIndexData (int p_num)
 {
   if (global.quiet == 0) { 
     fprintf (stderr, "index: %.2d\n", p_num); fflush(stderr);
@@ -147,10 +141,7 @@ static void UpdateIndexData (p_num)
 
 
 /* print the time of track currently read */
-static void UpdateTimeData (p_min, p_sec, p_frm)
-	int p_min;
-	int p_sec;
-	int p_frm;
+static void UpdateTimeData (int p_min, int p_sec, int p_frm)
 {
   if (global.quiet == 0) {
     fprintf (stderr, "time: %.2d:%.2d.%.2d\r", p_min, p_sec, p_frm); 
@@ -158,8 +149,7 @@ static void UpdateTimeData (p_min, p_sec, p_frm)
   }
 }
 
-void AnalyzeQchannel ( frame )
-	unsigned frame;
+void AnalyzeQchannel ( unsigned frame )
 {
     subq_chnl *sub_ch;
 
@@ -230,9 +220,7 @@ static int can_read_illleadout()
 unsigned
 find_an_off_sector __PR((unsigned lSector, unsigned SectorBurstVal));
 
-unsigned find_an_off_sector(lSector, SectorBurstVal)
-	unsigned lSector;
-	unsigned SectorBurstVal;
+unsigned find_an_off_sector(unsigned lSector, unsigned SectorBurstVal)
 {
 	long track_of_start = Get_Track(lSector);
 	long track_of_end = Get_Track(lSector + SectorBurstVal -1);
@@ -354,8 +342,7 @@ static unsigned is_multisession()
    the start of the leadout. If this is not supported, we subtract
    a constant of SESSIONSECTORS sectors (found heuristically).
  */
-static unsigned get_end_of_last_audio_track(mult_off)
-	unsigned mult_off;
+static unsigned get_end_of_last_audio_track(unsigned mult_off)
 {
    unsigned retval;
 
@@ -430,9 +417,9 @@ typedef struct TOC {	/* structure of table of contents (cdrom) */
 struct iterator {
 	int index;
 	int startindex;
-	void        (*reset)        __PR(( struct iterator *this ));
-	struct TOC *(*getNextTrack) __PR(( struct iterator *this ));
-	int         (*hasNextTrack) __PR(( struct iterator *this ));
+	void        (*reset)        __PR(( struct iterator *_this ));
+	struct TOC *(*getNextTrack) __PR(( struct iterator *_this ));
+	int         (*hasNextTrack) __PR(( struct iterator *_this ));
 };
 
 
@@ -450,8 +437,7 @@ struct iterator {
    So the length of the last track in case of Cd-Extra
    has to be fixed.
  */
-unsigned FixupTOC(no_tracks)
-	unsigned no_tracks;
+unsigned FixupTOC(unsigned no_tracks)
 {
     unsigned mult_off;
     unsigned offset = 0;
@@ -541,8 +527,7 @@ unsigned FixupTOC(no_tracks)
     return offset;
 }
 
-static int cddb_sum(n)
-	int n;
+static int cddb_sum(int n)
 {
   int ret;
 
@@ -651,8 +636,7 @@ void calc_cdindex_id()
 
 
 #if defined CDDB_SUPPORT
-static void emit_cddb_form(fname_baseval)
-	char *fname_baseval;
+static void emit_cddb_form(char *fname_baseval)
 {
   static struct iterator i;
   unsigned first_audio;
@@ -759,10 +743,7 @@ static void emit_cddb_form(fname_baseval)
 int readn __PR((register int fd, register char *ptr, register int nbytes));
 int writen __PR((register int fd, register char *ptr, register int nbytes));
 
-int readn(fd, ptr, nbytes)
-	register int	fd;
-	register char	*ptr;
-	register int	nbytes;
+int readn(int fd, char *ptr, int nbytes)
 {
 	int	nread;
 
@@ -781,10 +762,7 @@ int readn(fd, ptr, nbytes)
 	return nread;
 }
 
-int writen(fd, ptr, nbytes)
-	register int	fd;
-	register char	*ptr;
-	register int	nbytes;
+int writen(int fd, char *ptr, int nbytes)
 {
 	int	nleft, nwritten;
 
@@ -807,13 +785,10 @@ int writen(fd, ptr, nbytes)
 
 #define	SOCKBUFF	2048
 
-int
+static int
 process_cddb_titles __PR((int sock_fd, char *inbuff, int readbytes));
-int
-process_cddb_titles(sock_fd, inbuff, readbytes)
-	int	sock_fd;
-	char	*inbuff;
-	int	readbytes;
+static int
+process_cddb_titles(int sock_fd, char *inbuff, int readbytes)
 {
 	int	finished = 0;
 	char	*p = inbuff;
@@ -925,11 +900,11 @@ request_titles()
 	he = gethostbyname("freedb.freedb.org");
 	if (he == NULL) {
 		perror("cddb cannot resolve freedb host: ");
-		he = malloc(sizeof(struct hostent));
+		he = (struct hostent*)malloc(sizeof(struct hostent));
 		memset(he, 0 , sizeof(struct hostent));
 		he->h_length = 4;
-		he->h_addr_list = malloc(4);
-		he->h_addr_list[0] = malloc(4);
+		he->h_addr_list = (char**)malloc(sizeof(char**));
+		he->h_addr_list[0] = (char*)malloc(sizeof(char*));
 		((struct in_addr *)(he->h_addr_list[0]))->s_addr =
 			/* kingfisher.berlios.de          freedb.freedb.de */
 			 htonl(UINT_C(0xc3254d85));	/*0xc2610412*/
@@ -944,7 +919,7 @@ request_titles()
 	if (se == NULL) {
 		se = getservbyname("cddbp", "tcp");
 		if (se == NULL) {
-			se = malloc(sizeof(struct servent));
+			se = (struct servent*)malloc(sizeof(struct servent));
 			memset(se, 0 , sizeof(struct servent));
 			se->s_port = htons(8880);
 #if	0	
@@ -1170,8 +1145,7 @@ static char *
 ascii2html __PR((unsigned char *inp));
 
 static char *
-ascii2html(inp)
-	unsigned char *inp;
+ascii2html(unsigned char *inp)
 {
 	static unsigned char outline[300];
 	unsigned char *outp = outline;
@@ -1199,8 +1173,7 @@ ascii2html(inp)
 }
 #undef copy_translation
 
-static void emit_cdindex_form(fname_baseval)
-	char *fname_baseval;
+static void emit_cdindex_form(char *fname_baseval)
 {
   FILE *cdindex_form;
   char fname[200];
@@ -1390,8 +1363,7 @@ static void dump_cdtext_info()
 
 
 
-static void dump_extra_info(from)
-	unsigned int from;
+static void dump_extra_info(unsigned int from)
 {
 #ifdef CD_EXTRA
   unsigned char *p;
@@ -1428,8 +1400,7 @@ static void dump_extra_info(from)
 
 static char *quote __PR((unsigned char *string));
 
-static char *quote(string)
-	unsigned char * string;
+static char *quote(unsigned char *string)
 {
   static char result[200];
   unsigned char *p = (unsigned char *)result;
@@ -1449,8 +1420,7 @@ static char *quote(string)
 
 static void DisplayToc_with_gui __PR(( unsigned long dw ));
 
-static void DisplayToc_with_gui( dw )
-	unsigned long dw;
+static void DisplayToc_with_gui(unsigned long dw)
 {
 	unsigned mins;
 	unsigned secnds;
@@ -1584,8 +1554,7 @@ static void DisplayToc_with_gui( dw )
 
 static void DisplayToc_no_gui __PR(( unsigned long dw ));
 
-static void DisplayToc_no_gui( dw )
-	unsigned long dw;
+static void DisplayToc_no_gui(unsigned long dw)
 {
 	unsigned mins;
 	unsigned secnds;
@@ -1813,7 +1782,7 @@ static void DisplayToc_no_gui( dw )
 					int j;
 					char *o = global.tracktitle[jj] != NULL
 						? (char *)global.tracktitle[jj]
-						: "";
+						: (char *)"";
 					for ( j = 0;
 					      j < (maxlen - ((int)strlen(o) + 12)/8);
 					      j++)
@@ -1896,8 +1865,7 @@ void DisplayToc ( )
 
 static void Read_MCN_toshiba __PR(( subq_chnl **sub_ch ));
 
-static void Read_MCN_toshiba( sub_ch )
-	subq_chnl **sub_ch;
+static void Read_MCN_toshiba(subq_chnl **sub_ch)
 {
 	if (Toshiba3401() != 0 && global.quiet == 0
 	    && ((*sub_ch) != 0
@@ -1999,9 +1967,7 @@ static void Get_Set_MCN()
 
 static void Read_ISRC_toshiba __PR(( subq_chnl **sub_ch, unsigned tr ));
 
-static void Read_ISRC_toshiba( sub_ch, tr )
-	subq_chnl **sub_ch;
-	unsigned tr;
+static void Read_ISRC_toshiba(subq_chnl **sub_ch, unsigned tr)
 {
 	if (Toshiba3401() != 0) {
 		int j;
@@ -2024,8 +1990,7 @@ static void Read_ISRC_toshiba( sub_ch, tr )
 
 static void Get_Set_ISRC __PR(( unsigned tr ));
 
-static void Get_Set_ISRC( tr )
-	unsigned tr;
+static void Get_Set_ISRC( unsigned tr )
 {
 	subq_chnl *sub_ch;
 	subq_track_isrc * subq_tr;
@@ -2282,9 +2247,7 @@ void Read_MCN_ISRC()
  * For modern drives implement a second method. If the drive supports
  * reading of subchannel data, do direct reads.
  */
-static int GetIndexOfSector( sec, track )
-	unsigned sec;
-	unsigned track;
+static int GetIndexOfSector(unsigned sec, unsigned track)
 {
     subq_chnl *sub_ch;
 
@@ -2335,11 +2298,7 @@ static int GetIndexOfSector( sec, track )
 static int
 ScanBackwardFrom __PR((unsigned sec, unsigned limit, int *where, unsigned track));
 
-static int ScanBackwardFrom(sec, limit, where, track)
-	unsigned sec;
-	unsigned limit;
-	int *where;
-	unsigned track;
+static int ScanBackwardFrom(unsigned sec, unsigned limit, int *where, unsigned track)
 {
 	unsigned lastindex = 0;
 	unsigned mysec = sec;
@@ -2406,11 +2365,7 @@ static int ScanBackwardFrom(sec, limit, where, track)
 
 #ifdef	USE_LINEAR_SEARCH
 static int linear_search	__PR((int searchInd, unsigned int Start, unsigned int End, unsigned track));
-static int linear_search(searchInd, Start, End, track)
-	int searchInd;
-	unsigned Start;
-	unsigned End;
-	unsigned track;
+static int linear_search(int searchInd, unsigned Start, unsigned End, unsigned track)
 {
       int l = Start;
       int r = End;
@@ -2435,11 +2390,7 @@ static int linear_search(searchInd, Start, End, track)
 #ifndef	USE_LINEAR_SEARCH
 #undef DEBUG_BINSEARCH
 static int binary_search	__PR((int searchInd, unsigned int Start, unsigned int End, unsigned track));
-static int binary_search(searchInd, Start, End, track)
-	int searchInd;
-	unsigned Start;
-	unsigned End;
-	unsigned track;
+static int binary_search(int searchInd, unsigned Start, unsigned End, unsigned track)
 {
       int l = Start;
       int r = End;
@@ -2495,9 +2446,7 @@ static void
 register_index_position __PR((int IndexOffset, index_list **last_index_entry));
 
 static void
-register_index_position(IndexOffset, last_index_entry)
-	int IndexOffset;
-	index_list **last_index_entry;
+register_index_position(int IndexOffset, index_list **last_index_entry)
 {
       index_list *indexentry;
 
@@ -2522,10 +2471,7 @@ register_index_position(IndexOffset, last_index_entry)
 #undef DEBUG_INDLIST
 /* experimental code */
 /* search for indices (audio mode required) */
-unsigned ScanIndices( track, cd_index, bulk )
-	unsigned track;
-	unsigned cd_index;
-	int bulk;
+unsigned ScanIndices(unsigned track, unsigned cd_index, int bulk)
 {
   /* scan for indices. */
   /* look at last sector of track. */
@@ -2676,8 +2622,7 @@ unsigned ScanIndices( track, cd_index, bulk )
 
 static unsigned char MCN[14];
 
-static void Set_MCN( MCN_arg )
-	unsigned char *MCN_arg;
+static void Set_MCN( unsigned char *MCN_arg )
 {
 	memcpy(MCN, MCN_arg, 14);
 	MCN[13] = '\0';
@@ -2693,11 +2638,7 @@ static TOC g_toc [MAXTRK+1]; /* hidden track + 100 regular tracks */
 
 /*#define IS_AUDIO(i) (!(g_toc[i].bFlags & 0x04))*/
 
-int TOC_entries ( tracks, a, b, binvalid )
-	unsigned tracks;
-	unsigned char *a;
-	unsigned char *b;
-	int binvalid;
+int TOC_entries ( unsigned tracks, unsigned char *a, unsigned char *b, int binvalid )
 {
 	int i;
 	for (i = 1; i <= (int)tracks; i++) {
@@ -2717,7 +2658,7 @@ int TOC_entries ( tracks, a, b, binvalid )
 				  &g_toc[i].secs,
 				  &g_toc[i].frms);
 		} else {
-			p = b + 8*(i-1);
+			p = (unsigned char*)b + 8*(i-1);
 			g_toc[i].bFlags = p[1];
 			g_toc[i].bTrack = p[2];
 			g_toc[i].ISRC[0] = 0;
@@ -2734,15 +2675,7 @@ int TOC_entries ( tracks, a, b, binvalid )
 	return 0;
 }
 
-void toc_entry( nr, flag, tr, ISRC, lba, m, s, f )
-	unsigned nr;
-	unsigned flag;
-	unsigned tr;
-	unsigned char *ISRC;
-	unsigned long lba;
-	int	m;
-	int	s;
-	int	f;
+void toc_entry(unsigned nr, unsigned flag, unsigned tr, unsigned char *ISRC, unsigned long lba, int m, int s, int f)
 {
 	if (nr > MAXTRK) return;
 
@@ -2759,16 +2692,13 @@ void toc_entry( nr, flag, tr, ISRC, lba, m, s, f )
 	g_toc[nr].frms = f;
 }
 
-int patch_real_end (sector)
-	unsigned long sector;
+int patch_real_end (unsigned long sector)
 {
 	g_toc[cdtracks+1].dwStartSector = sector;
 	return 0;
 }
 
-static int patch_cd_extra (track, sector)
-	unsigned track;
-	unsigned long sector;
+static int patch_cd_extra (unsigned track, unsigned long sector)
 {
 	if (track <= cdtracks)
 		g_toc[track].dwStartSector = sector;
@@ -2785,9 +2715,7 @@ static int restrict_tracks_illleadout()
 	return 0;
 }
 
-static void Set_ISRC ( track, ISRC_arg )
-	int track;
-	const unsigned char *ISRC_arg;
+static void Set_ISRC (int track, const unsigned char *ISRC_arg )
 {
 	if (track <= (int)cdtracks) {
 		memcpy(Get_ISRC(track), ISRC_arg, 16);
@@ -2795,135 +2723,119 @@ static void Set_ISRC ( track, ISRC_arg )
 }
 
 
-unsigned char *Get_ISRC ( p_track )
-	unsigned long p_track;
+unsigned char *Get_ISRC (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].ISRC;
 	return NULL;
 }
 
-static void patch_to_audio ( p_track )
-	unsigned long p_track;
+static void patch_to_audio (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		g_toc[p_track].bFlags &= ~0x04;
 }
 
-int Get_Flags ( p_track )
-	unsigned long p_track;
+int Get_Flags (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].bFlags;
 	return -1;
 }
 
-int Get_Mins ( p_track )
-	unsigned long p_track;
+int Get_Mins (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].mins;
 	return -1;
 }
 
-int Get_Secs ( p_track )
-	unsigned long p_track;
+int Get_Secs (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].secs;
 	return -1;
 }
 
-int Get_Frames ( p_track )
-	unsigned long p_track;
+int Get_Frames (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].frms;
 	return -1;
 }
 
-int Get_Preemphasis ( p_track )
-	unsigned long p_track;
+int Get_Preemphasis (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].bFlags & 0x01;
 	return -1;
 }
 
-int Get_Copyright ( p_track )
-	unsigned long p_track;
+int Get_Copyright (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].bFlags & 0x02;
 	return -1;
 }
 
-int Get_Datatrack ( p_track )
-	unsigned long p_track;
+int Get_Datatrack (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].bFlags & 0x04;
 	return -1;
 }
 
-int Get_Channels ( p_track )
-	unsigned long p_track;
+int Get_Channels (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].bFlags & 0x08;
 	return -1;
 }
 
-int Get_Tracknumber ( p_track )
-	unsigned long p_track;
+int Get_Tracknumber (unsigned long p_track)
 {
 	if (p_track <= cdtracks)
 		return g_toc[p_track].bTrack;
 	return -1;
 }
 
-int useHiddenTrack __PR(( void ));
+static int useHiddenTrack __PR(( void ));
 
-int useHiddenTrack ()
+static int useHiddenTrack ()
 {
 	return 0;
 }
 
 
 
-static void it_reset __PR(( struct iterator *this ));
+static void it_reset __PR(( struct iterator *_this ));
 
-static void it_reset( this )
-	struct iterator *this;
+static void it_reset(struct iterator *_this)
 {
-	this->index = this->startindex;
+	_this->index = _this->startindex;
 }
 
 
-static int it_hasNextTrack __PR(( struct iterator *this ));
-static struct TOC *it_getNextTrack __PR(( struct iterator *this ));
+static int it_hasNextTrack __PR(( struct iterator *_this ));
+static struct TOC *it_getNextTrack __PR(( struct iterator *_this ));
 
-static int it_hasNextTrack( this )
-	struct iterator *this;
+static int it_hasNextTrack( struct iterator *_this )
 {
-	return this->index <= (int)cdtracks+1;
+	return _this->index <= (int)cdtracks+1;
 }
 
 
 
-static struct TOC *it_getNextTrack( this )
-	struct iterator *this;
+static struct TOC *it_getNextTrack(struct iterator *_this)
 {
 	/* if ( (*this->hasNextTrack)(this) == 0 ) return NULL; */
-	if ( this->index > (int)cdtracks+1 ) return NULL;
+	if ( _this->index > (int)cdtracks+1 ) return NULL;
 
-	return &g_toc[ this->index++ ];
+	return &g_toc[ _this->index++ ];
 }
 
 
-static void InitIterator ( iter, p_track )
-	struct iterator *iter;
-	unsigned long p_track;
+static void InitIterator ( struct iterator *iter, unsigned long p_track )
 {
 	if (iter == NULL) return;
 
@@ -2938,7 +2850,7 @@ static struct iterator *NewIterator ()
 {
 	struct iterator *retval;
 
-	retval = malloc (sizeof(struct iterator));
+	retval = (struct iterator*)malloc (sizeof(struct iterator));
 	if (retval != NULL) {
 		InitIterator(retval, 1);
 	}
@@ -2946,8 +2858,7 @@ static struct iterator *NewIterator ()
 }
 
 
-long Get_AudioStartSector ( p_track )
-	unsigned long p_track;
+long Get_AudioStartSector (unsigned long p_track)
 {
 #if	1
 	if (p_track == CDROM_LEADOUT)
@@ -2978,8 +2889,7 @@ long Get_AudioStartSector ( p_track )
 }
 
 
-long Get_StartSector ( p_track )
-	unsigned long p_track;
+long Get_StartSector(unsigned long p_track)
 {
 #if	1
 	if (p_track == CDROM_LEADOUT)
@@ -3006,8 +2916,7 @@ long Get_StartSector ( p_track )
 }
 
 
-long Get_EndSector ( p_track )
-	unsigned long p_track;
+long Get_EndSector (unsigned long p_track)
 {
 #if	1
 	if (p_track <= cdtracks)
@@ -3099,8 +3008,7 @@ long LastAudioTrack ( )
 	return j;
 }
 
-long Get_LastSectorOnCd( p_track )
-	unsigned long p_track;
+long Get_LastSectorOnCd(unsigned long p_track)
 {
 	long LastSec = 0;
 	static struct iterator i;
@@ -3126,8 +3034,7 @@ long Get_LastSectorOnCd( p_track )
 	return LastSec;
 }
 
-int Get_Track( sector )
-	unsigned long sector;
+int Get_Track(unsigned long sector)
 {
 	static struct iterator i;
 	if (i.reset == NULL) InitIterator(&i, 1);
@@ -3150,9 +3057,7 @@ int Get_Track( sector )
 	return -1;
 }
 
-int CheckTrackrange( from, upto )
-	unsigned long from;
-	unsigned long upto;
+int CheckTrackrange(unsigned long from, unsigned long upto)
 {
 	static struct iterator i;
 	if (i.reset == NULL) InitIterator(&i, from);
