@@ -640,13 +640,13 @@ rscsiscmd(SCSI *scgp, int fd, struct scg_cmd *sp)
 		sp->size, sp->flags,
 		sp->cdb_len, sp->sense_len,
 		sp->timeout);
-	movebytes(sp->cdb.cmd_cdb, &cbuf[ret], sp->cdb_len);
+	memmove(&cbuf[ret], sp->cdb.cmd_cdb, sp->cdb_len);
 	ret += sp->cdb_len;
 
 	if ((sp->flags & SCG_RECV_DATA) == 0 && sp->size > 0) {
 		amt = sp->size;
 		if ((ret + amt) <= sizeof(cbuf)) {
-			movebytes(sp->addr, &cbuf[ret], amt);
+			memmove(&cbuf[ret], sp->addr, amt);
 			ret += amt;
 			amt = 0;
 		}
@@ -718,7 +718,7 @@ rscsireadbuf(SCSI *scgp, int fd, char *buf, int count)
 		cnt = scglocal(scgp)->readbcnt;
 		if (cnt > n)
 			cnt = n;
-		movebytes(scglocal(scgp)->readbptr, buf, cnt);
+		memcpy(buf, scglocal(scgp)->readbptr, cnt);
 		scglocal(scgp)->readbptr += cnt;
 		scglocal(scgp)->readbcnt -= cnt;
 		amt += cnt;
