@@ -320,7 +320,7 @@ do_scg_cmd(scgp, sp)
 	if (sp->cdb_len > 12)
 		comerrno(EX_BAD, "Can't do %d byte command.\n", sp->cdb_len);
 
-	fillbytes(&req, sizeof(req), '\0');
+	memset(&req, 0, sizeof(req));
 
 	req.flags = SC_ASYNC;
 	if (sp->flags & SCG_RECV_DATA) {
@@ -333,7 +333,7 @@ do_scg_cmd(scgp, sp)
 	req.timeout_value = sp->timeout;
 	req.command_length = sp->cdb_len;
 
-	movebytes(&sp->cdb, req.scsi_cdb, 12);
+	memcpy(req.scsi_cdb, &sp->cdb, 12);
 	errno = 0;
 	ret = ioctl(scgp->fd, DKIOCMD, &req);
 
@@ -365,8 +365,8 @@ do_scg_cmd(scgp, sp)
 	sp->sense_count = 0;
 	sp->resid = 0;		/* AIX is the same rubbish as Linux here */
 
-	fillbytes(&sp->scb, sizeof(sp->scb), '\0');
-	fillbytes(&sp->u_sense.cmd_sense, sizeof(sp->u_sense.cmd_sense), '\0');
+	memset(&sp->scb, 0, sizeof(sp->scb));
+	memset(&sp->u_sense.cmd_sense, 0, sizeof(sp->u_sense.cmd_sense));
 
 	if (req.status_validity == 0) {
 		sp->error = SCG_NO_ERROR;
@@ -399,7 +399,7 @@ do_scg_sense(scgp, sp)
 	int		ret;
 	struct scg_cmd	s_cmd;
 
-	fillbytes((caddr_t)&s_cmd, sizeof(s_cmd), '\0');
+	memset((caddr_t)&s_cmd, 0, sizeof(s_cmd));
 	s_cmd.addr = sp->u_sense.cmd_sense;
 	s_cmd.size = sp->sense_len;
 	s_cmd.flags = SCG_RECV_DATA|SCG_DISRE_ENA;
