@@ -365,14 +365,14 @@ scgo_send(scgp)
 		Cmd.scsi_Flags |= SCSIF_WRITE;
 
 	Cmd.scsi_Command = malloc(sp->cdb_len);
-	movebytes(sp->cdb.cmd_cdb, Cmd.scsi_Command, sp->cdb_len);
+	memcpy(Cmd.scsi_Command, sp->cdb.cmd_cdb, sp->cdb_len);
 	Cmd.scsi_CmdLength = sp->cdb_len;
 	Cmd.scsi_Data = (void *) sp->addr;
 	Cmd.scsi_Length = sp->size;
 	Cmd.scsi_Actual = 0;
 
 	Cmd.scsi_SenseData = senseData;
-	fillbytes(Cmd.scsi_SenseData, sizeof(senseData), '\0');
+	memset(Cmd.scsi_SenseData, 0, sizeof(senseData));
 	if (sp->sense_len > sizeof(senseData))
 		Cmd.scsi_SenseLength = sizeof(senseData);
 	else if (sp->sense_len < 0)
@@ -394,13 +394,13 @@ scgo_send(scgp)
 		}
 	}
 
-	fillbytes(&sp->scb, sizeof(sp->scb), '\0');
-	fillbytes(&sp->u_sense.cmd_sense, sizeof(sp->u_sense.cmd_sense), '\0');
+	memset(&sp->scb, 0, sizeof(sp->scb));
+	memset(&sp->u_sense.cmd_sense, 0, sizeof(sp->u_sense.cmd_sense));
 	sp->resid = Cmd.scsi_Length - Cmd.scsi_Actual;
 	sp->sense_count = Cmd.scsi_SenseActual;
 	if (sp->sense_count > SCG_MAX_SENSE)
 		sp->sense_count = SCG_MAX_SENSE;
-	movebytes(Cmd.scsi_SenseData, sp->u_sense.cmd_sense, sp->sense_count);
+	memmove(sp->u_sense.cmd_sense, Cmd.scsi_SenseData, sp->sense_count);
 	sp->u_scb.cmd_scb[0] = Cmd.scsi_Status;
 
 	switch (ioreq->io_Error) {
