@@ -390,7 +390,7 @@ scgo_send(scgp)
 	}
 
 	/* Zero the structure... */
-	fillbytes(&suc, sizeof(suc), '\0');
+	memset(&suc, 0, sizeof(suc));
 
 	/* Read or write? */
 	if (sp->flags & SCG_RECV_DATA) {
@@ -402,7 +402,7 @@ scgo_send(scgp)
 	suc.suc_timeout = sp->timeout;
 
 	suc.suc_cdblen = sp->cdb_len;
-	movebytes(sp->cdb.cmd_cdb, suc.suc_cdb, suc.suc_cdblen);
+	memmove(suc.suc_cdb, sp->cdb.cmd_cdb, suc.suc_cdblen);
 
 	suc.suc_datalen = sp->size;
 	suc.suc_data = sp->addr;
@@ -417,8 +417,8 @@ scgo_send(scgp)
 		if (suc.suc_sus.sus_status != STS_GOOD)
 			sp->ux_errno = EIO;
 	}
-	fillbytes(&sp->scb, sizeof(sp->scb), '\0');
-	fillbytes(&sp->u_sense.cmd_sense, sizeof(sp->u_sense.cmd_sense), '\0');
+	memset(&sp->scb, 0, sizeof(sp->scb));
+	memset(&sp->u_sense.cmd_sense, 0, sizeof(sp->u_sense.cmd_sense));
 #if 0
 	/*
 	 * Unfortunalety, BSD/OS has no idea of DMA residual count.
@@ -431,7 +431,7 @@ scgo_send(scgp)
 #endif
 	if (sp->sense_count > SCG_MAX_SENSE)
 		sp->sense_count = SCG_MAX_SENSE;
-	movebytes(suc.suc_sus.sus_sense, sp->u_sense.cmd_sense, sp->sense_count);
+	memmove(sp->u_sense.cmd_sense, suc.suc_sus.sus_sense, sp->sense_count);
 	sp->u_scb.cmd_scb[0] = suc.suc_sus.sus_status;
 
 	switch (suc.suc_sus.sus_status) {
