@@ -452,7 +452,7 @@ scgo_send(scgp)
 	req.databuf = sp->addr;
 	req.datalen = sp->size;
 	req.datalen_used = 0;
-	fillbytes(req.sense, sizeof(req.sense), '\0');
+	memset(req.sense, 0, sizeof(req.sense));
 	if (sp->sense_len > sizeof(req.sense))
 		req.senselen = sizeof(req.sense);
 	else if (sp->sense_len < 0)
@@ -474,13 +474,13 @@ scgo_send(scgp)
 		if (req.retsts != SCCMD_OK)
 			sp->ux_errno = EIO;
 	}
-	fillbytes(&sp->scb, sizeof(sp->scb), '\0');
-	fillbytes(&sp->u_sense.cmd_sense, sizeof(sp->u_sense.cmd_sense), '\0');
+	memset(&sp->scb, 0, sizeof(sp->scb));
+	memset(&sp->u_sense.cmd_sense, 0, sizeof(sp->u_sense.cmd_sense));
 	sp->resid = req.datalen - req.datalen_used;
 	sp->sense_count = req.senselen_used;
 	if (sp->sense_count > SCG_MAX_SENSE)
 		sp->sense_count = SCG_MAX_SENSE;
-	movebytes(req.sense, sp->u_sense.cmd_sense, sp->sense_count);
+	memmove(sp->u_sense.cmd_sense, req.sense, sp->sense_count);
 	sp->u_scb.cmd_scb[0] = req.status;
 
 	switch (req.retsts) {
@@ -647,7 +647,7 @@ scgo_open(scgp, device)
 				"Open of %s failed", XPT_DEVICE);
 		return(-1);
 	}
-	fillbytes(&ccb, sizeof(union ccb), '\0');
+	memset(&ccb, 0, sizeof(union ccb));
 
 	/*
 	 * Get a list of up to CAM_MAXDEVS passthrough devices in the
@@ -918,14 +918,14 @@ scgo_send(scgp)
 	}
 
 	dev = scglocal(scgp)->cam_devices[scgp->fd];
-	fillbytes(&ccb->ccb_h, sizeof(struct ccb_hdr), '\0');
+	memset(&ccb->ccb_h, 0, sizeof(struct ccb_hdr));
 	ccb->ccb_h.path_id = dev->path_id;
 	ccb->ccb_h.target_id = dev->target_id;
 	ccb->ccb_h.target_lun = dev->target_lun;
 
 	/* Build the CCB */
-	fillbytes(&(&ccb->ccb_h)[1], sizeof(struct ccb_scsiio), '\0');
-	movebytes(sp->cdb.cmd_cdb, &ccb->csio.cdb_io.cdb_bytes, sp->cdb_len);
+	memset(&(&ccb->ccb_h)[1], 0, sizeof(struct ccb_scsiio));
+	memmove(&ccb->csio.cdb_io.cdb_bytes, sp->cdb.cmd_cdb, sp->cdb_len);
 
 	/*
 	 * Set the data direction flags.
@@ -991,8 +991,8 @@ scgo_send(scgp)
 		sp->ux_errno = EIO;
 
 	/* Pass the result back up */
-	fillbytes(&sp->scb, sizeof(sp->scb), '\0');
-	fillbytes(&sp->u_sense.cmd_sense, sizeof(sp->u_sense.cmd_sense), '\0');
+	memset(&sp->scb, 0, sizeof(sp->scb));
+	memset(&sp->u_sense.cmd_sense, 0, sizeof(sp->u_sense.cmd_sense));
 	sp->resid = ccb->csio.resid;
 	sp->sense_count = SSD_FULL_SIZE - ccb->csio.sense_resid;
 
@@ -1003,7 +1003,7 @@ scgo_send(scgp)
 		sp->sense_count = SCG_MAX_SENSE;
 
 	/* Copy the sense data out */
-	movebytes(&ccb->csio.sense_data, &sp->u_sense.cmd_sense, sp->sense_count);
+	memmove(&sp->u_sense.cmd_sense, &ccb->csio.sense_data, sp->sense_count);
 
 	sp->u_scb.cmd_scb[0] = ccb->csio.scsi_status;
 
