@@ -299,7 +299,7 @@ scgo_send(scgp)
 		return (0);
 	}
 
-	fillbytes((caddr_t)&sctl_io, sizeof(sctl_io), '\0');
+	memset((caddr_t)&sctl_io, 0, sizeof(sctl_io));
 
 	flags = 0;
 /*	flags = SCTL_INIT_WDTR|SCTL_INIT_SDTR;*/
@@ -310,7 +310,7 @@ scgo_send(scgp)
 
 	sctl_io.flags		= flags;
 
-	movebytes(&sp->cdb, sctl_io.cdb, sp->cdb_len);
+	memmove(sctl_io.cdb, &sp->cdb, sp->cdb_len);
 	sctl_io.cdb_length	= sp->cdb_len;
 
 	sctl_io.data_length	= sp->size;
@@ -360,7 +360,7 @@ error("cdb_status: %X, size: %d xfer: %d\n", sctl_io.cdb_status, sctl_io.data_le
 		if (sctl_io.sense_status != S_GOOD) {
 			sp->sense_count = 0;
 		} else {
-			movebytes(sctl_io.sense, sp->u_sense.cmd_sense, sp->sense_count);
+			memmove(sp->u_sense.cmd_sense, sctl_io.sense, sp->sense_count);
 		}
 
 	}
