@@ -60,7 +60,7 @@ LOCAL	int	scgo_aisatapi	__PR((SCSI *scgp));
 LOCAL	int	scgo_areset	__PR((SCSI *scgp, int what));
 LOCAL	int	scgo_asend	__PR((SCSI *scgp));
 
-LOCAL scg_ops_t ata_ops = {
+EXPORT scg_ops_t scg_ata_ops = {
 	scgo_asend,
 	scgo_aversion,
 	scgo_aopen,
@@ -979,8 +979,8 @@ scgo_asend(SCSI *scgp)
 		return (0);
 	}
 	/* initialize */
-	fillbytes((caddr_t) & sg_cgc, sizeof (sg_cgc), '\0');
-	fillbytes((caddr_t) & sense_cgc, sizeof (sense_cgc), '\0');
+	memset((caddr_t) & sg_cgc, 0, sizeof (sg_cgc));
+	memset((caddr_t) & sense_cgc, 0, sizeof (sense_cgc));
 
 	if (sp->flags & SCG_RECV_DATA) {
 		sg_cgc.data_direction = CGC_DATA_READ;
