@@ -412,7 +412,7 @@ do_scg_cmd(SCSI *scgp, struct scg_cmd *sp)
 		use_local = 1;
 		dbp = &local[LEAD];
 		if (!inward) 
-			movebytes(sp->addr, dbp, sp->size);
+			memcpy(dbp, sp->addr, sp->size);
 	}
 
 	whp = (struct pg_write_hdr *)(dbp - WHSIZE);
@@ -487,10 +487,10 @@ do_scg_cmd(SCSI *scgp, struct scg_cmd *sp)
 	}
 
 	if (use_local && inward)
-		movebytes(dbp, sp->addr, i);
+		memcpy(sp->addr, dbp, i);
 
-	fillbytes(&sp->scb, sizeof(sp->scb), '\0');
-        fillbytes(&sp->u_sense.cmd_sense, sizeof(sp->u_sense.cmd_sense), '\0');
+	memset(&sp->scb, 0, sizeof(sp->scb));
+        memset(&sp->u_sense.cmd_sense, 0, sizeof(sp->u_sense.cmd_sense));
 
 	sp->error = SCG_NO_ERROR;
 	i = rhp->scsi?2:0;
@@ -517,7 +517,7 @@ do_scg_sense(SCSI *scgp, struct scg_cmd *sp)
         int             ret;
         struct scg_cmd  s_cmd;
 
-        fillbytes((caddr_t)&s_cmd, sizeof(s_cmd), '\0');
+        memset((caddr_t)&s_cmd, 0, sizeof(s_cmd));
         s_cmd.addr = (caddr_t)sp->u_sense.cmd_sense;
         s_cmd.size = sp->sense_len;
         s_cmd.flags = SCG_RECV_DATA|SCG_DISRE_ENA;
