@@ -294,7 +294,7 @@ scgo_open(SCSI *scgp, char *device)
 	if (device != NULL && *device != '\0') {
 #ifdef USE_ATA
 		if(strncmp(device, "ATAPI", 5) == 0) {
-			scgp->ops = &ata_ops;
+			scgp->ops = &scg_ata_ops;
 			return (SCGO_OPEN(scgp, device));
 		} else
 #endif
@@ -627,7 +627,7 @@ sg_initdev(SCSI *scgp, int f)
 	n = fcntl(f, F_GETFL);	/* Be very proper about this */
 	fcntl(f, F_SETFL, n|O_NONBLOCK);
 
-	fillbytes((caddr_t)&sg_rep, sizeof(struct sg_header), '\0');
+	memset((caddr_t)&sg_rep, 0, sizeof(struct sg_header));
 	sg_rep.hd.reply_len = sizeof(struct sg_header);
 
 	while (read(f, &sg_rep, sizeof(sg_rep)) >= 0 || errno != EAGAIN)
@@ -1053,7 +1053,7 @@ scgo_send(SCSI *scgp)
 	if (scglocal(scgp)->isold > 0) {
 		return (sg_rwsend(scgp));
 	}
-	fillbytes((caddr_t)&sg_io, sizeof(sg_io), '\0');
+	memset((caddr_t)&sg_io, 0, sizeof(sg_io));
 
 	sg_io.interface_id = 'S';
 
@@ -1268,22 +1268,22 @@ sg_rwsend(SCSI *scgp)
 	 * location if this location differs from sg_rq.
 	 * Never read/write directly to sgp->some_int !!!!!
 	 */
-	fillbytes((caddr_t)&sg_rq, sizeof(struct sg_header), '\0');
+	memset((caddr_t)&sg_rq, 0, sizeof(struct sg_header));
 
 	sg_rq.hd.pack_len = pack_len;
 	sg_rq.hd.reply_len = reply_len;
 	sg_rq.hd.pack_id = scglocal(scgp)->pack_id++;
-/*	sg_rq.hd.result = 0;	not needed because of fillbytes() */
+/*	sg_rq.hd.result = 0;	not needed because of memset() */
 
 	if ((caddr_t)&sg_rq != (caddr_t)sgp)
-		movebytes((caddr_t)&sg_rq, (caddr_t)sgp, sizeof(struct sg_header));
+		memcpy((caddr_t)sgp, (caddr_t)&sg_rq, sizeof(struct sg_header));
 #else
-	fillbytes((caddr_t)sgp, sizeof(struct sg_header), '\0');
+	memset((caddr_t)sgp, 0, sizeof(struct sg_header));
 
 	sgp->hd.pack_len = pack_len;
 	sgp->hd.reply_len = reply_len;
 	sgp->hd.pack_id = scglocal(scgp)->pack_id++;
-/*	sgp->hd.result = 0;	not needed because of fillbytes() */
+/*	sgp->hd.result = 0;	not needed because of memset() */
 #endif
 	if (amt == 12)
 		sgp->hd.twelve_byte = 1;
@@ -1294,7 +1294,7 @@ sg_rwsend(SCSI *scgp)
 	}
 	if (!(sp->flags & SCG_RECV_DATA)) {
 		if ((void *)sp->addr != (void *)&sgp->buf[amt])
-			movebytes(sp->addr, &sgp->buf[amt], sp->size);
+			memcpy(&sgp->buf[amt], sp->addr, sp->size);
 		amt += sp->size;
 	}
 #ifdef	SG_GET_BUFSIZE
@@ -1315,7 +1315,7 @@ sg_rwsend(SCSI *scgp)
 	}
 
 	if (sp->addr == scglocal(scgp)->SCSIbuf) {
-		movebytes(sgp, sgp2, sizeof(struct sg_header));
+		memcpy(sgp2, sgp, sizeof(struct sg_header));
 		sgp = sgp2;
 	}
 	sgp->hd.sense_buffer[0] = 0;
@@ -1325,7 +1325,7 @@ sg_rwsend(SCSI *scgp)
 	}
 
 	if (sp->flags & SCG_RECV_DATA && ((void *)sgp->buf != (void *)sp->addr)) {
-		movebytes(sgp->buf, sp->addr, sp->size);
+		memcpy(sp->addr, sgp->buf, sp->size);
 	}
 	sp->ux_errno = GETINT(sgp->hd.result);		/* Unaligned read */
 	sp->error = SCG_NO_ERROR;
@@ -1391,7 +1391,7 @@ sg_rwsend(SCSI *scgp)
 		sp->u_scb.cmd_scb[0] = status_byte;
 		if (status_byte & ST_CHK_COND) {
 			sp->sense_count = sgp->hd.sense_len;
-			movebytes(sgp->hd.sense_buffer, sp->u_sense.cmd_sense, sp->sense_count);
+			memcpy(sp->u_sense.cmd_sense, sgp->hd.sense_buffer, sp->sense_count);
 		}
 	} else
 #endif
@@ -1422,7 +1422,7 @@ sg_rwsend(SCSI *scgp)
 		if (sgp->hd.sense_buffer[0] != 0) {
 			sp->scb.chk = 1;
 			sp->sense_count = SG_MAX_SENSE;
-			movebytes(sgp->hd.sense_buffer, sp->u_sense.cmd_sense, sp->sense_count);
+			memcpy(sp->u_sense.cmd_sense, sgp->hd.sense_buffer, sp->sense_count);
 			if (sp->ux_errno == 0)
 				sp->ux_errno = EIO;
 		}
