@@ -368,8 +368,8 @@ scgo_send(scgp)
 		sp->ux_errno = EIO;
 		return (0);
 	}
-	fillbytes(&req, sizeof(req), '\0');
-	movebytes(sp->cdb.cmd_cdb, &req.sr_cdb, sp->cdb_len);
+	memset(&req, 0, sizeof(req));
+	memcpy(&req.sr_cdb, sp->cdb.cmd_cdb, sp->cdb_len);
 	if (sp->size) {
 		req.sr_dma_dir = SR_DMA_WR;
 		if (sp->flags & SCG_RECV_DATA)
@@ -402,7 +402,7 @@ scgo_send(scgp)
 		sp->sense_count = SCG_MAX_SENSE;
 	if (sp->sense_count < 0)
 		sp->sense_count = 0;
-	movebytes(&req.sr_esense, sp->u_sense.cmd_sense, sp->sense_count);
+	memcpy(sp->u_sense.cmd_sense, &req.sr_esense, sp->sense_count);
 	sp->resid = sp->size - req.sr_dma_xfr;
 
 	switch (req.sr_io_status) {
