@@ -353,7 +353,7 @@ extern	char		**environ;
 	environ = 0;
 	if ((cmd = popen(SCSI_CFG,"r")) == NULL) {
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Error popen() for \"%s\"",
 				SCSI_CFG);
 		environ = evsave;
@@ -364,7 +364,7 @@ extern	char		**environ;
 	if (fgets(lines, MAXLINE, cmd) == NULL) {
 		errno = EIO;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Error reading popen() for \"%s\"",
 				SCSI_CFG);
 		return (-1);
@@ -372,14 +372,14 @@ extern	char		**environ;
 		nlm = atoi(lines);
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile, "-------------------- \n");
-		js_fprintf((FILE *)scgp->errfile, "mscsi lines = %d\n", nlm);
-		js_fprintf((FILE *)scgp->errfile, "-------------------- \n");
+		fprintf((FILE *)scgp->errfile, "-------------------- \n");
+		fprintf((FILE *)scgp->errfile, "mscsi lines = %d\n", nlm);
+		fprintf((FILE *)scgp->errfile, "-------------------- \n");
 	}
 
 	if (pclose(cmd) == -1) {
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Error pclose() for \"%s\"",
 				SCSI_CFG);
 		return (-1);
@@ -403,14 +403,14 @@ extern	char		**environ;
 		/* the order the lines will be received in will determine */
 		/* the device name we can use to open the device         */
 
-		js_snprintf(sconf, sizeof(sconf),
+		snprintf(sconf, sizeof(sconf),
 			SCSI_DEV, l + 1); /* enumeration starts with 1 */
 
 		evsave = environ;
 		environ = 0;
 		if ((cmd = popen(sconf,"r")) == NULL) {
 			if (scgp->errstr)
-				js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+				snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 					"Error popen() for \"%s\"",
 					sconf);
 			environ = evsave;
@@ -423,7 +423,7 @@ extern	char		**environ;
 
 		if (pclose(cmd) == -1) {
 			if (scgp->errstr)
-				js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+				snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 					"Error pclose() for \"%s\"",
 					sconf);
 			return (-1);
@@ -437,27 +437,27 @@ extern	char		**environ;
 					&cmtbl[l].lun);
 
 		if ( strstr(cmtbl[l].typ, T_DISK) != NULL ) {
-			js_snprintf(cmtbl[l].dev,  sizeof(cmtbl[l].dev),
+			snprintf(cmtbl[l].dev,  sizeof(cmtbl[l].dev),
 					DEV_SDSK, ++nSdsk);
 		}
 
 		if ( strstr(cmtbl[l].typ, T_CDROM) != NULL ) {
-			js_snprintf(cmtbl[l].dev,  sizeof(cmtbl[l].dev),
+			snprintf(cmtbl[l].dev,  sizeof(cmtbl[l].dev),
 					DEV_SROM, ++nSrom);
 		}
 
 		if ( strstr(cmtbl[l].typ, T_TAPE) != NULL ) {
-			js_snprintf(cmtbl[l].dev, sizeof(cmtbl[l].dev),
+			snprintf(cmtbl[l].dev, sizeof(cmtbl[l].dev),
 					DEV_STP, ++nStp);
 		}
 
 		if ( strstr(cmtbl[l].typ, T_FLOPPY) != NULL ) {
-			js_snprintf(cmtbl[l].dev, sizeof(cmtbl[l].dev),
+			snprintf(cmtbl[l].dev, sizeof(cmtbl[l].dev),
 					DEV_SFLP, ++nSflp);
 		}
 
 		if (scgp->debug > 0) {
-			js_fprintf((FILE *)scgp->errfile,
+			fprintf((FILE *)scgp->errfile,
 				"%-4s = %5s(%d,%d,%d,%d) -> %s\n",
 				cmtbl[l].typ,
 				cmtbl[l].drv,
@@ -471,12 +471,12 @@ extern	char		**environ;
 	}
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile, "-------------------- \n");
-		js_fprintf((FILE *)scgp->errfile, "%2d DISK  \n", nSdsk + 1);
-		js_fprintf((FILE *)scgp->errfile, "%2d CD-ROM\n", nSrom + 1);
-		js_fprintf((FILE *)scgp->errfile, "%2d TAPE  \n", nStp  + 1);
-		js_fprintf((FILE *)scgp->errfile, "%2d FLOPPY\n", nSflp + 1);
-		js_fprintf((FILE *)scgp->errfile, "-------------------- \n");
+		fprintf((FILE *)scgp->errfile, "-------------------- \n");
+		fprintf((FILE *)scgp->errfile, "%2d DISK  \n", nSdsk + 1);
+		fprintf((FILE *)scgp->errfile, "%2d CD-ROM\n", nSrom + 1);
+		fprintf((FILE *)scgp->errfile, "%2d TAPE  \n", nStp  + 1);
+		fprintf((FILE *)scgp->errfile, "%2d FLOPPY\n", nSflp + 1);
+		fprintf((FILE *)scgp->errfile, "-------------------- \n");
 	}
 
 	/* ok, now let's sort this array of scsi devices	*/
@@ -485,7 +485,7 @@ extern	char		**environ;
 
 	if (scgp->debug > 0) {
 		for (l = 0; l < nlm; l++)
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 			"%-4s = %5s(%d,%d,%d,%d) -> %s\n",
 			cmtbl[l].typ,
 			cmtbl[l].drv,
@@ -494,7 +494,7 @@ extern	char		**environ;
 			cmtbl[l].tgt,
 			cmtbl[l].lun,
 			cmtbl[l].dev);
-		js_fprintf((FILE *)scgp->errfile, "-------------------- \n");
+		fprintf((FILE *)scgp->errfile, "-------------------- \n");
 	}
 
 	/* find root disk controller to make it scg 0     	*/
@@ -522,7 +522,7 @@ extern	char		**environ;
 	}
 
 	if (!(ide_rootdisk) && (scgp->debug > 0)) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 			"root = %5s(%d,%d,%d,%d) -> %s\n",
 			cmtbl[t].drv,
 			cmtbl[t].hba,
@@ -530,7 +530,7 @@ extern	char		**environ;
 			cmtbl[t].tgt,
 			cmtbl[t].lun,
 			cmtbl[t].dev);
-		js_fprintf((FILE *)scgp->errfile, "-------------------- \n");
+		fprintf((FILE *)scgp->errfile, "-------------------- \n");
 	}
 
 	/* calculate scg from drv, hba and bus 			*/
@@ -607,7 +607,7 @@ extern	char		**environ;
 				if ((fd = open(dname, (O_RDONLY | O_NONBLOCK))) < 0) {
 					sdidevs[s][t][l].valid = 0;
 					if (scgp->debug > 0) {
-						js_fprintf((FILE *)scgp->errfile,
+						fprintf((FILE *)scgp->errfile,
 							"%5s(%d,%d,%d,%d) -> %s open() failed: errno = %d (%s)\n",
 							cmtbl[mscsi].drv,
 							cmtbl[mscsi].hba,
@@ -622,7 +622,7 @@ extern	char		**environ;
 				}
 
 				if (scgp->debug > 0) {
-					js_fprintf((FILE *)scgp->errfile,
+					fprintf((FILE *)scgp->errfile,
 						"%d,%d,%d => %5s(%d,%d,%d,%d) -> %d : %s \n",
 						s, t, l,
 						cmtbl[mscsi].drv,
@@ -643,9 +643,9 @@ extern	char		**environ;
 	}
 
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile, "-------------------- \n");
-		js_fprintf((FILE *)scgp->errfile, "nopen = %d devices   \n", nopen);
-		js_fprintf((FILE *)scgp->errfile, "-------------------- \n");
+		fprintf((FILE *)scgp->errfile, "-------------------- \n");
+		fprintf((FILE *)scgp->errfile, "nopen = %d devices   \n", nopen);
+		fprintf((FILE *)scgp->errfile, "-------------------- \n");
 	}
 
 	return (nopen);
@@ -667,7 +667,7 @@ scgo_open(scgp, device)
 	if (busno >= MAX_SCG || tgt >= MAX_TGT || tlun >= MAX_LUN) {
 		errno = EINVAL;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 				"Illegal value for busno, target or lun '%d,%d,%d'",
 				busno, tgt, tlun);
 		return (-1);
@@ -689,7 +689,7 @@ scgo_open(scgp, device)
 	if (*device != '\0') {          /* we don't allow old dev usage */
 		errno = EINVAL;
 		if (scgp->errstr)
-			js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
+			snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 			"Open by 'devname' no longer supported on this OS");
 		return (-1);
 	}
@@ -744,7 +744,7 @@ scgo_getbuf(scgp, amt)
 	long	amt;
 {
 	if (scgp->debug > 0) {
-		js_fprintf((FILE *)scgp->errfile,
+		fprintf((FILE *)scgp->errfile,
 			"scgo_getbuf: %ld bytes\n", amt);
 	}
 	scgp->bufbase = valloc((size_t)(amt));
@@ -912,12 +912,12 @@ scgo_send(scgp)
 
 		if (scsiusercmd) {	/* Use SCSIUSERCMD ioctl() */
 			if (scgp->debug > 1) {
-				js_fprintf((FILE *)scgp->errfile, "calling SCSIUSERCMD ioctl()\n");
+				fprintf((FILE *)scgp->errfile, "calling SCSIUSERCMD ioctl()\n");
 			}
 
 			if ((ioctlStatus = ioctl(scgp->fd, SCSIUSERCMD, &(scsi_cmd.cmd))) < 0) {
 				if (scgp->debug > 1) {
-					js_fprintf((FILE *)scgp->errfile, "returning from SCSIUSERCMD ioctl()\n");
+					fprintf((FILE *)scgp->errfile, "returning from SCSIUSERCMD ioctl()\n");
 				}
 				if (errno == EINTR)
 					continue;
@@ -932,7 +932,7 @@ scgo_send(scgp)
 			}
 
 			if (scgp->debug > 1) {
-				js_fprintf((FILE *)scgp->errfile, "returning from SCSIUSERCMD ioctl()\n");
+				fprintf((FILE *)scgp->errfile, "returning from SCSIUSERCMD ioctl()\n");
 			}
 			cp_sco2scg(&scsi_cmd, sp);
 			sp->ux_errno = errno;
@@ -962,20 +962,20 @@ scgo_send(scgp)
 
 			if (scgp->debug > 0) {
 				if (errno != 0)
-					js_fprintf((FILE *)scgp->errfile, "ux_errno: %d (%s) \n", sp->ux_errno, strerror(sp->ux_errno) );
+					fprintf((FILE *)scgp->errfile, "ux_errno: %d (%s) \n", sp->ux_errno, strerror(sp->ux_errno) );
 				if (sp->u_scb.cmd_scb[0] != 0)
-					js_fprintf((FILE *)scgp->errfile, "tgt_stat: %d \n", sp->u_scb.cmd_scb[0] );
+					fprintf((FILE *)scgp->errfile, "tgt_stat: %d \n", sp->u_scb.cmd_scb[0] );
 			}
 			break;
 
 		} else {		/* Use SCSIUSERCMD2 ioctl() */
 			if (scgp->debug > 1) {
-				js_fprintf((FILE *)scgp->errfile, "calling SCSIUSERCMD2 ioctl()\n");
+				fprintf((FILE *)scgp->errfile, "calling SCSIUSERCMD2 ioctl()\n");
 			}
 
 			if ((ioctlStatus = ioctl(scgp->fd, SCSIUSERCMD2, &scsi_cmd)) < 0) {
 				if (scgp->debug > 1) {
-					js_fprintf((FILE *)scgp->errfile, "returning from SCSIUSERCMD2 ioctl()\n");
+					fprintf((FILE *)scgp->errfile, "returning from SCSIUSERCMD2 ioctl()\n");
 				}
 				if (errno == EINTR)
 					continue;
@@ -989,7 +989,7 @@ scgo_send(scgp)
 				return (0);
 			}
 			if (scgp->debug > 1) {
-				js_fprintf((FILE *)scgp->errfile, "returning from SCSIUSERCMD2 ioctl()\n");
+				fprintf((FILE *)scgp->errfile, "returning from SCSIUSERCMD2 ioctl()\n");
 			}
 
 			cp_sco2scg(&scsi_cmd, sp);
@@ -1003,9 +1003,9 @@ scgo_send(scgp)
 
 			if (scgp->debug > 0) {
 				if (errno != 0)
-					js_fprintf((FILE *)scgp->errfile, "ux_errno: %d (%s) \n", sp->ux_errno, strerror(sp->ux_errno) );
+					fprintf((FILE *)scgp->errfile, "ux_errno: %d (%s) \n", sp->ux_errno, strerror(sp->ux_errno) );
 				if (sp->u_scb.cmd_scb[0] != 0)
-					js_fprintf((FILE *)scgp->errfile, "tgt_stat: %d \n", sp->u_scb.cmd_scb[0] );
+					fprintf((FILE *)scgp->errfile, "tgt_stat: %d \n", sp->u_scb.cmd_scb[0] );
 			}
 			break;
 
