@@ -380,9 +380,9 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 	}
 
 	/* clear command block */
-	fillbytes((caddr_t)&SRBlock.u.cmd.cdb_st, sizeof(SRBlock.u.cmd.cdb_st), '\0');
+	memset((caddr_t)&SRBlock.u.cmd.cdb_st, 0, sizeof(SRBlock.u.cmd.cdb_st));
 	/* copy cdrecord command into SRB */
-	movebytes(&sp->cdb, &SRBlock.u.cmd.cdb_st, sp->cdb_len);
+	memmove(&SRBlock.u.cmd.cdb_st, &sp->cdb, sp->cdb_len);
 
 	/* Build SRB command block */
 	SRBlock.cmd = SRB_Command;
@@ -406,7 +406,7 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 		if (sp->size > 0) {
 			SRBlock.flags |= SRB_Write;
 			if (scgp->bufbase != sp->addr) {/* Copy only if data not in ASPI-Mem */
-				movebytes(sp->addr, scgp->bufbase, sp->size);
+				memmove(scgp->bufbase, sp->addr, sp->size);
 			}
 		} else {
 			SRBlock.flags |= SRB_NoTransfer;
@@ -458,7 +458,7 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 			if (sp->flags & SCG_RECV_DATA) {	/* We read data */
 				if (sp->addr && sp->size) {
 					if (scgp->bufbase != sp->addr)	/* Copy only if data not in ASPI-Mem */
-						movebytes(scgp->bufbase, sp->addr, SRBlock.u.cmd.data_len);
+						memmove(sp->addr, scgp->bufbase, SRBlock.u.cmd.data_len);
 					ptr = (UCHAR*)sp->addr;
 					sp->resid = sp->size - SRBlock.u.cmd.data_len;/*nicht bertragene bytes. Korrekt berechnet???*/
 				}
@@ -471,8 +471,8 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 				ptr = (UCHAR*)&SRBlock.u.cmd.cdb_st;
 				ptr += SRBlock.u.cmd.cdb_len;
 
-				fillbytes(&sp->u_sense.Sense, sizeof(sp->u_sense.Sense), '\0');
-				movebytes(ptr, &sp->u_sense.Sense, sp->sense_len);
+				memset(&sp->u_sense.Sense, 0, sizeof(sp->u_sense.Sense));
+				memmove(&sp->u_sense.Sense, ptr, sp->sense_len);
 
 				sp->u_scb.cmd_scb[0] = SRBlock.u.cmd.target_status;
 				sp->ux_errno = EIO;	/* Spter differenzieren? */
@@ -490,15 +490,15 @@ static	SRB	SRBlock;			/* XXX makes it non reentrant */
 			ptr = (UCHAR*)&SRBlock.u.cmd.cdb_st;
 			ptr += SRBlock.u.cmd.cdb_len;
 
-			fillbytes(&sp->u_sense.Sense, sizeof(sp->u_sense.Sense), '\0');
-			movebytes(ptr, &sp->u_sense.Sense, sp->sense_len);
+			memset(&sp->u_sense.Sense, 0, sizeof(sp->u_sense.Sense));
+			memmove(&sp->u_sense.Sense, ptr, sp->sense_len);
 
 			sp->u_scb.cmd_scb[0] = SRBlock.u.cmd.target_status;
 		}
 		if (sp->flags & SCG_RECV_DATA) {
 			if (sp->addr && sp->size) {
 				if (scgp->bufbase != sp->addr)	/* Copy only if data not in ASPI-Mem */
-					movebytes(scgp->bufbase, sp->addr, SRBlock.u.cmd.data_len);
+					memmove(sp->addr, scgp->bufbase, SRBlock.u.cmd.data_len);
 			}
 		}
 #ifdef	really
