@@ -593,7 +593,7 @@ scgo_ucinfo(f, cp, debug)
 	struct dk_cinfo *cp;
 	int		debug;
 {
-	fillbytes(cp, sizeof(*cp), '\0');
+	memset(cp, 0, sizeof(*cp));
 
 	if (ioctl(f, DKIOCINFO, cp) < 0)
 		return (-1);
@@ -757,7 +757,7 @@ scgo_ureset(scgp, what)
 	if (what == SCG_RESET_NOP)
 		return (0);
 
-	fillbytes(&req, sizeof(req), '\0');
+	memset(&req, 0, sizeof(req));
 
 	if (what == SCG_RESET_TGT) {
 		req.uscsi_flags = USCSI_RESET | USCSI_SILENT;	/* reset target */
@@ -784,7 +784,7 @@ scgo_usend(scgp)
 		return (0);
 	}
 
-	fillbytes(&req, sizeof(req), '\0');
+	memset(&req, 0, sizeof(req));
 
 	req.uscsi_flags = USCSI_SILENT | USCSI_DIAGNOSE | USCSI_RQENABLE;
 
