@@ -592,7 +592,7 @@ scgo_send(scgp)
 	/*
 	 * copy cdrecord command into SRB
 	 */
-	movebytes(&sp->cdb, &(s.CDBByte), sp->cdb_len);
+	memmove(&(s.CDBByte), &sp->cdb, sp->cdb_len);
 
 	Event = CreateEvent(NULL, TRUE, FALSE, NULL);
 
