@@ -351,7 +351,7 @@ extern	scg_ops_t scg_dummy_ops;
 	if (scgp == NULL)
 		return ((SCSI *)0);
 
-	fillbytes(scgp, sizeof(*scgp), 0);
+	memset(scgp, 0, sizeof(*scgp));
 	scgp->ops	= &scg_dummy_ops;
 	scg_settarget(scgp, -1, -1, -1),
 	scgp->fd	= -1;
