@@ -43,6 +43,7 @@ static	char sccsid[] =
 #include <scg/scgcmd.h>
 #include <scg/scsireg.h>
 #include <scg/scsitransp.h>
+#include <sys/stat.h>
 #include "scgtimes.h"
 
 /*
@@ -151,7 +152,7 @@ EXPORT int scg__open(SCSI *scgp, char *device)
 {
 	int	ret;
 	scg_ops_t *ops;
-extern	scg_ops_t scg_std_ops;
+extern	scg_ops_t scg_std_ops, scg_ata_ops;
 
 	scgp->ops = &scg_std_ops;
 
@@ -161,6 +162,20 @@ extern	scg_ops_t scg_std_ops;
 			scgp->ops = ops;
 	}
 
+	if(device) {
+		// Check if we were given a device name, and if so,
+		// switch to ATAPI if it's an ATAPI device
+		struct stat s;
+		if(!stat(device, &s)) {
+			if(S_ISBLK(s.st_mode)) {
+				// It's a block device -- now let's determine
+				// the type...
+				if(major(s.st_rdev) == 3) // IDE/ATAPI
+					scgp->ops=&scg_ata_ops;
+			}
+		}
+	}
+
 	ret = SCGO_OPEN(scgp, device);
 	if (ret < 0)
 		return (ret);
