@@ -345,28 +345,23 @@ EXPORT int format(	void (*fun)(char, long),
 
 #ifndef	NO_FLOATINGPOINT
 		case 'e':
-			if (fa.signific == -1)
-				fa.signific = 6;
-			dval = va_arg(args, double);
-			ftoes(buf, dval, 0, fa.signific);
-			count += prbuf(buf, &fa);
-			continue;
 		case 'f':
-			if (fa.signific == -1)
-				fa.signific = 6;
-			dval = va_arg(args, double);
-			ftofs(buf, dval, 0, fa.signific);
-			count += prbuf(buf, &fa);
-			continue;
 		case 'g':
+		{
 			if (fa.signific == -1)
 				fa.signific = 6;
-			if (fa.signific == 0)
+			if (*fmt == 'g' && fa.signific == 0)
 				fa.signific = 1;
+			char format[16];
+			if(fa.fldwidth)
+				snprintf(format, 16, "_%u.%u%c", fa.fldwidth, fa.signific, *fmt);
+			else
+				snprintf(format, 16, "_%c", *fmt);
+			format[0]='%';
 			dval = va_arg(args, double);
-			gcvt(dval, fa.signific, buf);
-			count += prbuf(buf, &fa);
+			count += snprintf(buf, 512, format, dval);
 			continue;
+		}
 #else
 #	ifdef	USE_FLOATINGARGS
 		case 'e':
