@@ -72,24 +72,12 @@ LOCAL	char	fmtspecs[] = "#?*&+";
 |
 +---------------------------------------------------------------------------*/
 /* VARARGS3 */
-#ifdef	PROTOTYPES
 int getargs(int *pac, char *const **pav, const char *fmt, ...)
-#else
-int getargs(pac, pav, fmt, va_alist)
-	int	*pac;
-	char	**pav[];
-	char	*fmt;
-	va_dcl
-#endif
 {
 	va_list	args;
 	int	ret;
 
-#ifdef	PROTOTYPES
 	va_start(args, fmt);
-#else
-	va_start(args);
-#endif
 	ret = _getargs(pac, pav, fmt, TRUE, args);
 	va_end(args);
 	return (ret);
@@ -102,24 +90,12 @@ int getargs(pac, pav, fmt, va_alist)
 |
 +---------------------------------------------------------------------------*/
 /* VARARGS3 */
-#ifdef	PROTOTYPES
 int getallargs(int *pac, char *const **pav, const char *fmt, ...)
-#else
-int getallargs(pac, pav, fmt, va_alist)
-	int	*pac;
-	char	**pav[];
-	char	*fmt;
-	va_dcl
-#endif
 {
 	va_list	args;
 	int	ret;
 
-#ifdef	PROTOTYPES
 	va_start(args, fmt);
-#else
-	va_start(args);
-#endif
 	for (;; (*pac)--, (*pav)++) {
 		if ((ret = _getargs(pac, pav, fmt, TRUE, args)) != NOTAFLAG)
 			break;
@@ -134,10 +110,7 @@ int getallargs(pac, pav, fmt, va_alist)
 |	get next non flag type argument (i.e. a file)
 |
 +---------------------------------------------------------------------------*/
-int getfiles(pac, pav, fmt)
-	int		*pac;
-	char *const	*pav[];
-	const char	*fmt;
+int getfiles(int *pac, char * const *pav[], const char * fmt)
 {
 	return (_getargs(pac, pav, fmt, FALSE, va_dummy));
 }
@@ -157,12 +130,7 @@ int getfiles(pac, pav, fmt)
 |
 |
 +---------------------------------------------------------------------------*/
-/*LOCAL*/ int _getargs(pac, pav, fmt, setargs, args)
-	register int		*pac;
-	register char	*const	**pav;
-		 const char	*fmt;
-		BOOL		setargs;
-		va_list		args;
+/*LOCAL*/ int _getargs(int *pac, char * const **pav, const char *fmt, BOOL setargs, va_list args)
 {
 	const	 char	*argp;
 		 int	ret;
@@ -190,10 +158,7 @@ int getfiles(pac, pav, fmt)
 | check if *pargp is a file type argument
 |
 +---------------------------------------------------------------------------*/
-LOCAL int dofile(pac, pav, pargp)
-	register int		*pac;
-	register char *const	**pav;
-		 const char	**pargp;
+LOCAL int dofile(int *pac, char * const **pav, const char **pargp)
 {
 	register const char	*argp = *pargp;
 
@@ -244,13 +209,7 @@ LOCAL int dofile(pac, pav, pargp)
 |	in this case, va_list may be a dummy arg.
 |
 +---------------------------------------------------------------------------*/
-LOCAL int doflag(pac, pav, argp, fmt, setargs, oargs)
-		int		*pac;
-		char	*const	**pav;
-	register const char	*argp;
-	register const char	*fmt;
-		BOOL		setargs;
-		va_list		oargs;
+LOCAL int doflag(int *pac, char * const **pav, const char *argp, const char *fmt, BOOL setargs, va_list oargs)
 {
 	char	argstr[2];
 	long	val;
@@ -614,11 +573,7 @@ typedef struct {
 	char	type;
 } sflags;
 
-LOCAL int dosflags(argp, fmt, setargs, oargs)
-	register const char	*argp;
-	register const char	*fmt;
-		BOOL		setargs;
-		va_list		oargs;
+LOCAL int dosflags(const char *argp, const char *fmt, BOOL setargs, va_list oargs)
 {
 #define	MAXSF	32
 		 sflags	sf[MAXSF];
@@ -735,8 +690,7 @@ LOCAL int dosflags(argp, fmt, setargs, oargs)
 |	Otherwise raise the getarg_bad_format condition.
 |
 +---------------------------------------------------------------------------*/
-LOCAL int checkfmt(fmt)
-	const char	*fmt;
+LOCAL int checkfmt(const char *fmt)
 {
 	char	c;
 
@@ -760,8 +714,7 @@ LOCAL int checkfmt(fmt)
 |	contains a valid flag identifier.
 |
 +---------------------------------------------------------------------------*/
-static int checkeql(str)
-	register const char *str;
+static int checkeql(const char *str)
 {
 	register unsigned char c;
 
