@@ -32,8 +32,7 @@ extern	int	errno;
 #undef	seterrno
 #endif
 
-int seterrno(err)
-	int	err;
+int seterrno(int err)
 {
 	int	old = errno;
 
