@@ -21,9 +21,7 @@
 #include "io.h"
 
 EXPORT void
-file_raise(f,flg)
-	register FILE *f;
-	int flg;
+file_raise(FILE *f, int flg)
 {
 	int	oflag;
 extern	int	_io_glflag;
