@@ -21,9 +21,7 @@
 #include "io.h"
 
 EXPORT FILE *
-fileopen (name, mode)
-	const char	*name;
-	const char	*mode;
+fileopen (const char *name, const char *mode)
 {
 	int	ret;
 	int	omode = 0;
