@@ -52,7 +52,7 @@ fileread(FILE *f, void *buf, int len)
 			f->_ptr--;
 		}
 		n = f->_cnt >= len ? len : f->_cnt;
-		buf = (void *)movebytes (f->_ptr, buf, n);
+		buf = (void *)memmove (buf, f->_ptr, n);
 		f->_ptr += n;
 		f->_cnt -= n;
 		cnt += n;
