@@ -22,8 +22,7 @@
 #include <statdefs.h>
 
 EXPORT off_t
-filesize (f)
-	register FILE	*f;
+filesize (FILE *f)
 {
 	struct stat buf;
 
