@@ -52,7 +52,7 @@ filewrite (FILE *f, void *vbuf, int len)
 				break;
 		}
 		if ((n = f->_cnt >= len ? len : f->_cnt) > 0) {
-			f->_ptr = (unsigned char *)movebytes (buf, f->_ptr, n);
+			f->_ptr = (unsigned char *)memmove (f->_ptr, buf, n);
 			buf += n;
 			f->_cnt -= n;
 			cnt += n;
