@@ -21,8 +21,7 @@
 #include "io.h"
 
 EXPORT int
-fpipe (pipef)
-	FILE *pipef[];
+fpipe (FILE *pipef[])
 {
 	int filedes[2];
 
