@@ -24,14 +24,11 @@
 #include <errno.h>
 
 EXPORT int 
-_niread(f, buf, count)
-	int	f;
-	void	*buf;
-	int	count;
+_niread(int f, void *buf, int count)
 {
 	int ret;
  
-	while((ret = read(f, buf, count)) < 0 && geterrno() == EINTR)
+	while((ret = read(f, buf, count)) < 0 && errno == EINTR)
 		;
 	return(ret);
 }
