@@ -24,10 +24,7 @@
 #include <errno.h>
 
 EXPORT int 
-_nixread(f, buf, count)
-	int	f;
-	void	*buf;
-	int	count;
+_nixread(int f, void *buf, int count)
 {
 	register char *p = (char *)buf;
 	register int ret;
