@@ -24,10 +24,7 @@
 #include <errno.h>
 
 EXPORT int 
-_nixwrite(f, buf, count)
-	int	f;
-	void	*buf;
-	int	count;
+_nixwrite(int f, void *buf, int count)
 {
 	register char *p = (char *)buf;
 	register int ret;
@@ -35,7 +32,7 @@ _nixwrite(f, buf, count)
  
 	while(count > 0) {
 		while((ret = write(f, p, count)) < 0) {
-			if (geterrno() == EINTR)
+			if (errno == EINTR)
 				continue;
 			return (ret);	/* Any other error */
 		}
