@@ -25,9 +25,7 @@
 #endif
 
 EXPORT int
-_openfd(name, omode)
-	const char	*name;
-	int		omode;
+_openfd(const char *name, int omode)
 {
 	return (open(name, omode, 0666));
 }
