@@ -21,8 +21,7 @@
 #include "io.h"
 
 EXPORT int
-peekc (f)
-	FILE *f;
+peekc (FILE *f)
 {
 	int	c;
 
