@@ -159,16 +159,14 @@ void	usage		__PR((int excode));
 int	main		__PR((int argc, char *argv[]));
 
 int
-isonum_721 (p)
-	char	*p;
+isonum_721 (char *p)
 {
 	return ((p[0] & 0xff)
 		| ((p[1] & 0xff) << 8));
 }
 
 int
-isonum_723 (p)
-	char * p;
+isonum_723 (char *p)
 {
 #if 0
 	if (p[0] != p[3] || p[1] != p[2]) {
@@ -184,8 +182,7 @@ isonum_723 (p)
 }
 
 int
-isonum_731 (p)
-	char	*p;
+isonum_731 (char *p)
 {
 	return ((p[0] & 0xff)
 		| ((p[1] & 0xff) << 8)
@@ -194,8 +191,7 @@ isonum_731 (p)
 }
 
 int
-isonum_732(p)
-	char	*p;
+isonum_732(char *p)
 {
 	return ((p[3] & 0xff)
 		| ((p[2] & 0xff) << 8)
@@ -204,16 +200,13 @@ isonum_732(p)
 }
 
 int
-isonum_733 (p)
-	unsigned char	*p;
+isonum_733 (unsigned char *p)
 {
 	return (isonum_731 ((char *)p));
 }
 
 void
-printchars(s, n)
-	char	*s;
-	int	n;
+printchars(char *s, int n)
 {
 	int	i;
 	char	*p;
@@ -235,8 +228,7 @@ printchars(s, n)
  * Print date info from PVD
  */
 char *
-sdate(dp)
-	char	*dp;
+sdate(char *dp)
 {
 	static	char	d[30];
 
@@ -257,9 +249,7 @@ sdate(dp)
 }
 
 void
-dump_pathtab(block, size)
-	int	block;
-	int	size;
+dump_pathtab(int block, int size)
 {
     unsigned char * buf;
     int    offset;
@@ -322,10 +312,7 @@ dump_pathtab(block, size)
     free(buf);
 }
 
-int parse_rr(pnt, len, cont_flag)
-	unsigned char	*pnt;
-	int		len;
-	int		cont_flag;
+int parse_rr(unsigned char *pnt, int len, int cont_flag)
 {
 	int slen;
 	int xlen;
@@ -455,10 +442,7 @@ int parse_rr(pnt, len, cont_flag)
 }
 
 void
-find_rr(idr, pntp, lenp)
-	struct iso_directory_record *idr;
-	Uchar	**pntp;
-	int	*lenp;
+find_rr(struct iso_directory_record *idr, unsigned char **pntp, int *lenp)
 {
 	struct iso_xa_dir_record *xadp;
 	int len;
@@ -489,8 +473,7 @@ find_rr(idr, pntp, lenp)
 }
 
 int
-dump_rr(idr)
-	struct iso_directory_record *idr;
+dump_rr(struct iso_directory_record *idr)
 {
 	int len;
 	unsigned char * pnt;
@@ -513,8 +496,7 @@ char * months[12] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul",
 		       "Aug", "Sep", "Oct", "Nov", "Dec"};
 
 void
-dump_stat(extent)
-	int	extent;
+dump_stat(int extent)
 {
   int i;
   char outline[80];
@@ -593,8 +575,7 @@ dump_stat(extent)
 }
 
 void
-extract_file(idr)
-	struct iso_directory_record *idr;
+extract_file(struct iso_directory_record *idr)
 {
   int extent, len, tlen;
   unsigned char buff[2048];
@@ -614,10 +595,7 @@ extract_file(idr)
 }
 
 void
-parse_dir(rootname, extent, len)
-	char	*rootname;
-	int	extent;
-	int	len;
+parse_dir(char *rootname, int extent, int len)
 {
   char testname[PATH_MAX+1];
   struct todo * td;
@@ -750,8 +728,7 @@ parse_dir(rootname, extent, len)
 }
 
 void
-usage(excode)
-	int	excode;
+usage(int excode)
 {
 	errmsgno(EX_BAD, "Usage: %s [options] -i filename\n",
                 get_progname());
@@ -776,9 +753,7 @@ usage(excode)
 }
 
 int
-main(argc, argv)
-	int	argc;
-	char	*argv[];
+main(int argc, char **argv)
 {
 	int	cac;
 	char	* const *cav;
@@ -976,7 +951,7 @@ main(argc, argv)
   if( use_joliet || do_pvd)
     {
       int block = 16;
-      movebytes(&ipd, &jpd, sizeof(ipd));
+      memmove(&jpd, &ipd, sizeof(ipd));
       while( (unsigned char) jpd.type[0] != ISO_VD_END )
 	{
 		if(debug && (unsigned char) jpd.type[0] == ISO_VD_SUPPLEMENTARY )
