@@ -138,18 +138,10 @@ static int	jpathtab_size		__PR((int starting_extent));
  *	Any unknown character is set to '_'
  *
  */
-#ifdef	PROTOTYPES
 unsigned char 
 conv_charset(unsigned char c,
 	struct nls_table *inls,
 	struct nls_table *onls)
-#else
-unsigned char 
-conv_charset(c, inls, onls)
-	unsigned char c;
-	struct nls_table *inls;
-	struct nls_table *onls;
-#endif
 {
 	unsigned char uh,
 		      ul,
@@ -190,11 +182,7 @@ void
 #else
 static void
 #endif
-convert_to_unicode(buffer, size, source, inls)
-	unsigned char	*buffer;
-	int		size;
-	char		*source;
-	struct nls_table *inls;
+convert_to_unicode(unsigned char *buffer, int size, char *source, struct nls_table *inls)
 {
 	unsigned char	*tmpbuf;
 	int		i;
@@ -286,8 +274,7 @@ int
 #else
 static int
 #endif
-joliet_strlen(string)
-	const char	*string;
+joliet_strlen(const char *string)
 {
 	int		rtn;
 
@@ -315,8 +302,7 @@ joliet_strlen(string)
  *			appropriate fields.
  */
 static void
-get_joliet_vol_desc(jvol_desc)
-	struct iso_primary_descriptor	*jvol_desc;
+get_joliet_vol_desc(struct iso_primary_descriptor *jvol_desc)
 {
 	jvol_desc->type[0] = ISO_VD_SUPPLEMENTARY;
 
@@ -366,8 +352,7 @@ get_joliet_vol_desc(jvol_desc)
 }
 
 static void
-assign_joliet_directory_addresses(node)
-	struct directory	*node;
+assign_joliet_directory_addresses(struct directory *node)
 {
 	int		dir_size;
 	struct directory *dpnt;
@@ -397,8 +382,7 @@ assign_joliet_directory_addresses(node)
 }
 
 static void
-build_jpathlist(node)
-	struct directory	*node;
+build_jpathlist(struct directory *node)
 {
 	struct directory	*dpnt;
 
@@ -415,9 +399,7 @@ build_jpathlist(node)
 }/* build_jpathlist(... */
 
 static int
-joliet_compare_paths(r, l)
-	void const	*r;
-	void const	*l;
+joliet_compare_paths(void const *r, void const *l)
 {
 	struct directory const *ll = *(struct directory * const *) l;
 	struct directory const *rr = *(struct directory * const *) r;
@@ -675,9 +657,7 @@ generate_joliet_path_tables()
 }/* generate_path_tables(... */
 
 static void
-generate_one_joliet_directory(dpnt, outfile)
-	struct directory	*dpnt;
-	FILE			*outfile;
+generate_one_joliet_directory(struct directory *dpnt, FILE *outfile)
 {
 	unsigned int		dir_index;
 	char			*directory_buffer;
@@ -854,8 +834,7 @@ generate_one_joliet_directory(dpnt, outfile)
 }/* generate_one_joliet_directory(... */
 
 static int
-joliet_sort_n_finish(this_dir)
-	struct directory	*this_dir;
+joliet_sort_n_finish(struct directory *this_dir)
 {
 	struct directory_entry	*s_entry;
 	int			status = 0;
@@ -977,9 +956,7 @@ joliet_sort_n_finish(this_dir)
  * regular name of the file, not the 8.3 version.
  */
 static int
-joliet_compare_dirs(rr, ll)
-	const void	*rr;
-	const void	*ll;
+joliet_compare_dirs(const void *rr, const void *ll)
 {
 	char		*rpnt,
 			*lpnt;
@@ -1121,8 +1098,7 @@ joliet_compare_dirs(rr, ll)
  * Notes:		Returns 0 if OK, returns > 0 if an error occurred.
  */
 static int
-joliet_sort_directory(sort_dir)
-	struct directory_entry	**sort_dir;
+joliet_sort_directory(struct directory_entry **sort_dir)
 {
 	int			dcount = 0;
 	int			i;
@@ -1174,8 +1150,7 @@ joliet_sort_directory(sort_dir)
 }
 
 int
-joliet_sort_tree(node)
-	struct directory	*node;
+joliet_sort_tree(struct directory *node)
 {
 	struct directory	*dpnt;
 	int			ret = 0;
@@ -1198,9 +1173,7 @@ joliet_sort_tree(node)
 }
 
 static void
-generate_joliet_directories(node, outfile)
-	struct directory	*node;
-	FILE			*outfile;
+generate_joliet_directories(struct directory *node, FILE *outfile)
 {
 	struct directory *dpnt;
 
@@ -1231,8 +1204,7 @@ generate_joliet_directories(node, outfile)
  * Function to write the EVD for the disc.
  */
 static int
-jpathtab_write(outfile)
-	FILE	*outfile;
+jpathtab_write(FILE *outfile)
 {
 	/* Next we write the path tables */
 	xfwrite(jpath_table_l, 1, jpath_blocks << 11, outfile);
@@ -1246,8 +1218,7 @@ jpathtab_write(outfile)
 }
 
 static int
-jdirtree_size(starting_extent)
-	int	starting_extent;
+jdirtree_size(int starting_extent)
 {
 	assign_joliet_directory_addresses(root);
 	return 0;
@@ -1271,8 +1242,7 @@ jroot_gen()
 }
 
 static int
-jdirtree_write(outfile)
-	FILE	*outfile;
+jdirtree_write(FILE *outfile)
 {
 	generate_joliet_directories(root, outfile);
 	return 0;
@@ -1282,8 +1252,7 @@ jdirtree_write(outfile)
  * Function to write the EVD for the disc.
  */
 static int
-jvd_write(outfile)
-	FILE	*outfile;
+jvd_write(FILE *outfile)
 {
 	struct iso_primary_descriptor jvol_desc;
 
@@ -1299,8 +1268,7 @@ jvd_write(outfile)
  * Functions to describe padding block at the start of the disc.
  */
 static int
-jpathtab_size(starting_extent)
-	int	starting_extent;
+jpathtab_size(int starting_extent)
 {
 	jpath_table[0] = starting_extent;
 	jpath_table[1] = 0;
