@@ -38,6 +38,9 @@ static	char sccsid[] =
 #include "exclude.h"
 #include <unls.h>	/* For UNICODE translation */
 #include <schily.h>
+#ifdef HAVE_MAGIC_H
+#include <magic.h>
+#endif
 #ifdef UDF
 #include "udf.h"
 #endif
@@ -177,7 +180,10 @@ hce_mem	*hce;			/* libhfs/mkisofs extras */
 char	*hfs_boot_file = 0;	/* name of HFS boot file */
 int	gen_pt = 0;		/* generate HFS partition table */
 char	*autoname = 0;		/* AutoStart filename */
-char	*magic_file = 0;	/* name of magic file */
+#ifdef HAVE_MAGIC_H
+magic_t	magic_handle = 0;	/* handle for libmagic */
+char	*magic_filename = 0;	/* name of magic file */
+#endif
 int	probe = 0;		/* search files for HFS/Unix type */
 int	nomacfiles = 0;		/* don't look for Mac/Unix files */
 int	hfs_select = 0;		/* Mac/Unix types to select */
@@ -405,6 +411,12 @@ struct ld_option {
 
 static int	save_pname = 0;
 
+#ifdef __cplusplus
+#define ONE_DASH ld_option::ONE_DASH
+#define TWO_DASHES ld_option::TWO_DASHES
+#define NO_HELP ld_option::NO_HELP
+#endif
+
 static const struct ld_option ld_options[] =
 {
 	{{"nobak", no_argument, NULL, OPTION_NOBAK},
@@ -619,8 +631,10 @@ static const struct ld_option ld_options[] =
 	'h', NULL, "Create ISO9660/HFS hybrid", ONE_DASH},
 	{{"map", required_argument, NULL, 'H'},
 	'H', "MAPPING_FILE", "Map file extensions to HFS TYPE/CREATOR", ONE_DASH},
+#ifdef HAVE_MAGIC_H
 	{{"magic", required_argument, NULL, OPTION_MAGIC_FILE},
 	'\0', "FILE", "Magic file for HFS TYPE/CREATOR", ONE_DASH},
+#endif
 	{{"probe", no_argument, NULL, OPTION_PROBE},
 	'\0', NULL, "Probe all files for Apple/Unix file types", ONE_DASH},
 	{{"mac-name", no_argument, NULL, OPTION_MACNAME},
@@ -725,8 +739,7 @@ char
 #endif
 
 LOCAL void
-read_rcfile(appname)
-	char		*appname;
+read_rcfile(char *appname)
 {
 	FILE		*rcfile = (FILE *) NULL;
 	struct rcopts	*rco;
@@ -900,8 +913,7 @@ int	goof = 0;
 #endif
 
 LOCAL void
-susage(excode)
-	int		excode;
+susage(int excode)
 {
 	const char	*program_name = "mkisofs";
 
@@ -913,8 +925,7 @@ susage(excode)
 }
 
 LOCAL void
-usage(excode)
-	int		excode;
+usage(int excode)
 {
 	const char	*program_name = "mkisofs";
 
@@ -1017,9 +1028,7 @@ usage(excode)
  * of this wrong for ages (mkisofs had it wrong too for the longest time).
  */
 EXPORT int
-iso9660_date(result, crtime)
-	char	*result;
-	time_t	crtime;
+iso9660_date(char *result, time_t crtime)
 {
 	struct tm	*local;
 
@@ -1078,13 +1087,7 @@ hide_reloc_dir()
  * get pathnames from the command line, and then from given file
  */
 LOCAL char *
-get_pnames(argc, argv, opt, pname, pnsize, fp)
-	int	argc;
-	char	**argv;
-	int	opt;
-	char	*pname;
-	int	pnsize;
-	FILE	*fp;
+get_pnames(int argc, char **argv, int opt, char *pname, int pnsize, FILE *fp)
 {
 	int	len;
 
@@ -1114,9 +1117,7 @@ get_pnames(argc, argv, opt, pname, pnsize, fp)
 extern char	*cdrecord_data;
 
 EXPORT int
-main(argc, argv)
-	int		argc;
-	char		**argv;
+main(int argc, char **argv)
 {
 	struct directory_entry de;
 
@@ -1973,10 +1974,12 @@ main(argc, argv)
 		case OPTION_GEN_PT:
 			gen_pt = 1;
 			break;
+#ifdef HAVE_MAGIC_H
 		case OPTION_MAGIC_FILE:
-			magic_file = optarg;
+			magic_filename = optarg;
 			hfs_last = MAG_LAST;
 			break;
+#endif
 		case OPTION_AUTOSTART:
 			autoname = optarg;
 			/* gen_pt = 1; */
@@ -2285,7 +2288,10 @@ parse_input_files:
 	 */
 	if (!apple_hyb && !apple_ext) {
 		if (*afpfile || probe || use_mac_name || hfs_select ||
-				hfs_boot_file || magic_file ||
+				hfs_boot_file ||
+#ifdef HAVE_MAGIC_H
+			       	magic_filename ||
+#endif
 				hfs_ishidden() || gen_pt || autoname ||
 				afe_size || icon_pos || hfs_ct ||
 				hfs_icharset || hfs_ocharset) {
@@ -2342,7 +2348,11 @@ parse_input_files:
 		/* we need to search for all types of Apple/Unix files */
 		hfs_select = ~0;
 
-	if (apple_both && verbose && !(hfs_select || *afpfile || magic_file)) {
+	if (apple_both && verbose && !(hfs_select || *afpfile
+#ifdef HAVE_MAGIC_H
+			       	|| magic_filename
+#endif
+				)) {
 #ifdef	USE_LIBSCHILY
 		errmsgno(EX_BAD, 
 		"Warning: no Apple/Unix files will be decoded/mapped\n");
@@ -3163,8 +3173,7 @@ if (check_session == 0)
  * Find unescaped equal sign in graft pointer string.
  */
 EXPORT char *
-findgequal(s)
-	char	*s;
+findgequal(char *s)
 {
 	char	*p = s;
 
@@ -3180,9 +3189,7 @@ findgequal(s)
  * Find unescaped equal sign in string.
  */
 LOCAL char *
-escstrcpy(to, from)
-	char	*to;
-	char	*from;
+escstrcpy(char *to, char *from)
 {
 	char	*p = to;
 
@@ -3206,8 +3213,7 @@ escstrcpy(to, from)
 }
 
 EXPORT void *
-e_malloc(size)
-	size_t		size;
+e_malloc(size_t size)
 {
 	void		*pt = 0;
 
