@@ -35,6 +35,9 @@ extern char    *strdup();
 #include <dirdefs.h>
 #include <utypes.h>
 #include <standard.h>
+#ifdef HAVE_MAGIC_H
+#include <magic.h>
+#endif
 
 #ifdef	DVD_VIDEO
 #ifndef	UDF
@@ -370,7 +373,10 @@ extern hce_mem *hce;		/* libhfs/mkisofs extras */
 extern int      use_mac_name;	/* use Mac name for ISO9660/Joliet/RR */
 extern int      create_dt;	/* create the Desktp files */
 extern char    *hfs_boot_file;	/* name of HFS boot file */
-extern char    *magic_file;	/* magic file for CREATOR/TYPE matching */
+#ifdef HAVE_MAGIC_H
+extern magic_t	magic_handle;	/* libmagic handle */
+extern char    *magic_filename;	/* magic file for CREATOR/TYPE matching */
+#endif
 extern int      hfs_last;	/* order in which to process map/magic files */
 extern char    *deftype;	/* default Apple TYPE */
 extern char    *defcreator;	/* default Apple CREATOR */
@@ -440,7 +446,7 @@ extern void get_boot_entry	__PR((void));
 extern void new_boot_entry	__PR((void));
 
 /* boot.c */
-extern void sparc_boot_label __PR((char *label));
+extern void sparc_boot_label __PR((char const *label));
 extern void scan_sparc_boot __PR((char *files));
 extern int make_sun_label __PR((void));
 
@@ -455,7 +461,6 @@ extern void set_721 __PR((char *, unsigned int));
 extern void set_733 __PR((char *, unsigned int));
 extern int sort_directory __PR((struct directory_entry **, int));
 extern void generate_one_directory __PR((struct directory *, FILE *));
-extern void memcpy_max __PR((char *, char *, int));
 extern int oneblock_size __PR((int starting_extent));
 extern struct iso_primary_descriptor vol_desc;
 extern void xfwrite __PR((void *buffer, int count, int size, FILE * file));
@@ -530,7 +535,7 @@ extern void add_directory_hash __PR((dev_t, ino_t));
 extern struct file_hash *find_directory_hash __PR((dev_t, ino_t));
 extern void flush_file_hash __PR((void));
 extern int delete_file_hash __PR((struct directory_entry *));
-extern struct directory_entry *find_file_hash __PR((char *));
+extern struct directory_entry *find_file_hash __PR((char const *));
 extern void add_file_hash __PR((struct directory_entry *));
 
 extern int generate_rock_ridge_attributes __PR((char *, char *,
@@ -592,11 +597,6 @@ extern int gen_mac_label __PR((defer *));
 #endif
 extern int autostart __PR((void));
 
-/* libfile */
-
-extern char    *get_magic_match __PR((const char *));
-extern void clean_magic __PR((void));
-
 #endif	/* APPLE_HYB */
 
 extern char    *extension_record;
