@@ -49,11 +49,6 @@ extern char    *strdup(const char *);
 #define roundup(x, y)   ((((x)+((y)-1))/(y))*(y))
 #endif
 
-/*
- * Cannot debug memset() with gdb on Linux, so use fillbytes()
- */
-/*#define	memset(s, c, n)	fillbytes(s, n, c)*/
-
 #define TF_CREATE 1
 #define TF_MODIFY 2
 #define TF_ACCESS 4
@@ -64,8 +59,8 @@ static unsigned int	isonum_721	__PR((unsigned char *p));
 static unsigned int	isonum_723	__PR((unsigned char *p));
 static unsigned int	isonum_731	__PR((unsigned char *p));
 
-static	void	printasc	__PR((char *txt, unsigned char *p, int len));
-static	void	prbytes		__PR((char *txt, unsigned char *p, int len));
+static	void	printasc	__PR((char const *txt, unsigned char const *p, int len));
+static	void	prbytes		__PR((char const *txt, unsigned char const *p, int len));
 unsigned char	*parse_xa	__PR((unsigned char *pnt, int *lenp,
 					struct directory_entry *dpnt));
 EXPORT	int	rr_flags	__PR((struct iso_directory_record *idr));
@@ -137,16 +132,8 @@ FILE           *in_image = NULL;
  * Anyways, this allows the use of a scsi-generics type of interface on
  * Solaris.
  */
-#ifdef	__STDC__
 static int
 readsecs(int startsecno, void *buffer, int sectorcount)
-#else
-static int
-readsecs(startsecno, buffer, sectorcount)
-	int		startsecno;
-	void		*buffer;
-	int		sectorcount;
-#endif
 {
 	int		f = fileno(in_image);
 
@@ -173,10 +160,7 @@ readsecs(startsecno, buffer, sectorcount)
 #endif
 
 static void
-printasc(txt, p, len)
-	char		*txt;
-	unsigned char	*p;
-	int		len;
+printasc(char const *txt, unsigned char const *p, int len)
 {
 	int		i;
 
@@ -191,10 +175,7 @@ printasc(txt, p, len)
 }
 
 static void
-prbytes(txt, p, len)
-		char	*txt;
-	register Uchar	*p;
-	register int	len;
+prbytes(char const *txt, unsigned char const *p, int len)
 {
 	error("%s", txt);
 	while (--len >= 0)
@@ -203,10 +184,7 @@ prbytes(txt, p, len)
 }
 
 unsigned char *
-parse_xa(pnt, lenp, dpnt)
-	unsigned char	*pnt;
-	int		*lenp;
-	struct directory_entry *dpnt;
+parse_xa(unsigned char *pnt, int *lenp, struct directory_entry *dpnt)
 {
 	struct iso_xa_dir_record *xadp;
 	int		len = *lenp;
@@ -256,10 +234,7 @@ static	int		did_xa = 0;
 }
 
 EXPORT void
-find_rr(idr, pntp, lenp)
-	struct iso_directory_record *idr;
-	Uchar		**pntp;
-	int		*lenp;
+find_rr(struct iso_directory_record *idr, unsigned char **pntp, int *lenp)
 {
 	struct iso_xa_dir_record *xadp;
 	int		len;
@@ -292,10 +267,7 @@ find_rr(idr, pntp, lenp)
 }
 
 EXPORT int
-parse_rrflags(pnt, len, cont_flag)
-	Uchar	*pnt;
-	int	len;
-	int	cont_flag;
+parse_rrflags(unsigned char *pnt, int len, int cont_flag)
 {
 	int	ncount;
 	int	cont_extent;
@@ -369,8 +341,7 @@ parse_rrflags(pnt, len, cont_flag)
 }
 
 int
-rr_flags(idr)
-	struct iso_directory_record *idr;
+rr_flags(struct iso_directory_record *idr)
 {
 	int		len;
 	unsigned char	*pnt;
@@ -383,10 +354,7 @@ rr_flags(idr)
  * Parse the RR attributes so we can find the file name.
  */
 static int
-parse_rr(pnt, len, dpnt)
-	unsigned char	*pnt;
-	int		len;
-	struct directory_entry *dpnt;
+parse_rr(unsigned char *pnt, int len, struct directory_entry *dpnt)
 {
 	int		cont_extent;
 	int		cont_offset;
@@ -455,11 +423,7 @@ parse_rr(pnt, len, dpnt)
  * Returns 0 if the two files differ
  */
 static int
-check_rr_dates(dpnt, current, statbuf, lstatbuf)
-	struct directory_entry *dpnt;
-	struct directory_entry *current;
-	struct stat	*statbuf;
-	struct stat	*lstatbuf;
+check_rr_dates(struct directory_entry *dpnt, struct directory_entry *current, struct stat *statbuf, struct stat *lstatbuf)
 {
 	int		cont_extent;
 	int		cont_offset;
@@ -556,9 +520,7 @@ check_rr_dates(dpnt, current, statbuf, lstatbuf)
 }
 
 struct directory_entry **
-read_merging_directory(mrootp, nent)
-	struct iso_directory_record *mrootp;
-	int		*nent;
+read_merging_directory(struct iso_directory_record *mrootp, int *nent)
 {
 	unsigned char	*cpnt;
 	unsigned char	*cpnt1;
@@ -689,7 +651,7 @@ read_merging_directory(mrootp, nent)
 		if (rlen > 0) {
 			(*pnt)->total_rr_attr_size =
 						(*pnt)->rr_attr_size = rlen;
-			(*pnt)->rr_attributes = e_malloc(rlen);
+			(*pnt)->rr_attributes = (unsigned char*)e_malloc(rlen);
 			memcpy((*pnt)->rr_attributes, cpnt, rlen);
 			seen_rockridge = 1;
 		}
@@ -835,7 +797,7 @@ read_merging_directory(mrootp, nent)
 					 */
 					if (strlen(p) > 0) {
 						(*pnt)->table =
-						   e_malloc(strlen(p) + 4);
+						   (char*)e_malloc(strlen(p) + 4);
 						sprintf((*pnt)->table,
 							"%c\t%s\n",
 							*cpnt, p);
@@ -878,9 +840,7 @@ read_merging_directory(mrootp, nent)
  * Free any associated data related to the structures.
  */
 int
-free_mdinfo(ptr, len)
-	struct directory_entry **ptr;
-	int		len;
+free_mdinfo(struct directory_entry **ptr, int len)
 {
 	int		i;
 	struct directory_entry **p;
@@ -901,8 +861,7 @@ free_mdinfo(ptr, len)
 }
 
 static void
-free_directory_entry(dirp)
-	struct directory_entry *dirp;
+free_directory_entry(struct directory_entry *dirp)
 {
 	if (dirp->name != NULL)
 		free(dirp->name);
@@ -925,13 +884,7 @@ free_directory_entry(dirp)
  * over so we don't bother to write it out to the new session.
  */
 int
-check_prev_session(ptr, len, curr_entry, statbuf, lstatbuf, odpnt)
-	struct directory_entry **ptr;
-	int		len;
-	struct directory_entry *curr_entry;
-	struct stat	*statbuf;
-	struct stat	*lstatbuf;
-	struct directory_entry **odpnt;
+check_prev_session(struct directory_entry **ptr, int len, struct directory_entry *curr_entry, struct stat *statbuf, struct stat *lstatbuf, struct directory_entry **odpnt)
 {
 	int		i;
 	int		rr;
@@ -1029,8 +982,7 @@ found_it:
  * open_merge_image:  Open an existing image.
  */
 int
-open_merge_image(path)
-	char	*path;
+open_merge_image(char *path)
 {
 #ifndef	USE_SCG
 	in_image = fopen(path, "rb");
@@ -1065,8 +1017,7 @@ close_merge_image()
  * to the root directory for this image.
  */
 struct iso_directory_record *
-merge_isofs(path)
-	char	*path;
+merge_isofs(char *path)
 {
 	char		buffer[SECTOR_SIZE];
 	int		file_addr;
@@ -1121,10 +1072,7 @@ merge_isofs(path)
 }
 
 void
-merge_remaining_entries(this_dir, pnt, n_orig)
-	struct directory *this_dir;
-	struct directory_entry **pnt;
-	int		n_orig;
+merge_remaining_entries(struct directory *this_dir, struct directory_entry **pnt, int n_orig)
 {
 	int		i;
 	struct directory_entry *s_entry;
@@ -1287,9 +1235,7 @@ merge_remaining_entries(this_dir, pnt, n_orig)
  * location.  FIXME(eric).
  */
 static int
-merge_old_directory_into_tree(dpnt, parent)
-	struct directory_entry	*dpnt;
-	struct directory *parent;
+merge_old_directory_into_tree(struct directory_entry *dpnt, struct directory *parent)
 {
 	struct directory_entry **contents = NULL;
 	int		i;
@@ -1406,8 +1352,7 @@ merge_old_directory_into_tree(dpnt, parent)
 char           *cdrecord_data = NULL;
 
 int
-get_session_start(file_addr)
-	int		*file_addr;
+get_session_start(int *file_addr)
 {
 	char		*pnt;
 
@@ -1477,9 +1422,7 @@ get_session_start(file_addr)
  * directory entries, so that we can determine how large each directory is.
  */
 int
-merge_previous_session(this_dir, mrootp)
-	struct directory *this_dir;
-	struct iso_directory_record *mrootp;
+merge_previous_session(struct directory *this_dir, struct iso_directory_record *mrootp)
 {
 	struct directory_entry **orig_contents = NULL;
 	struct directory_entry *odpnt = NULL;
@@ -1593,8 +1536,7 @@ static struct dir_extent_link	*cl_dirs = NULL;
 static struct dir_extent_link	*re_dirs = NULL;
 
 static void
-check_rr_relocation(de)
-	struct directory_entry *de;
+check_rr_relocation(struct directory_entry *de)
 {
 	unsigned char   sector[SECTOR_SIZE];
 	unsigned char  *pnt = de->rr_attributes;
@@ -1613,7 +1555,7 @@ check_rr_relocation(de)
 #endif
 		}
 		if (strncmp((char *) pnt, "CL", 2) == 0) {
-			struct dir_extent_link *dlink = e_malloc(sizeof(*dlink));
+			struct dir_extent_link *dlink = (struct dir_extent_link*)e_malloc(sizeof(*dlink));
 
 			dlink->extent = isonum_733(pnt + 4);
 			dlink->de = de;
@@ -1621,7 +1563,7 @@ check_rr_relocation(de)
 			cl_dirs = dlink;
 
 		} else if (strncmp((char *) pnt, "RE", 2) == 0) {
-			struct dir_extent_link *dlink = e_malloc(sizeof(*dlink));
+			struct dir_extent_link *dlink = (struct dir_extent_link*)e_malloc(sizeof(*dlink));
 
 			dlink->extent = de->starting_block;
 			dlink->de = de;
