@@ -91,12 +91,7 @@ static int      reclimit;
 
 /* if we are using converted filenames, we don't want the '/' character */
 static void
-rstrncpy(t, f, c, inls, onls)
-	char	*t;
-	char	*f;
-	int	c;
-	struct nls_table *inls;
-	struct nls_table *onls;
+rstrncpy(char *t, char *f, int c, struct nls_table *inls, struct nls_table *onls)
 {
 	while (c-- && *f) {
 		*t = conv_charset(*f, inls, onls);
@@ -130,28 +125,12 @@ add_CE_entry()
 	reclimit = SECTOR_SIZE - 8;	/* Limit to one sector */
 }
 
-#ifdef __STDC__
 int
 generate_rock_ridge_attributes(char *whole_name, char *name,
 	                struct directory_entry * s_entry,
 	                struct stat * statbuf,
 	                struct stat * lstatbuf,
 	                int deep_opt)
-#else
-int
-generate_rock_ridge_attributes(whole_name, name,
-	                s_entry,
-	                statbuf,
-	                lstatbuf,
-	                deep_opt)
-	char           *whole_name;
-	char           *name;
-	struct directory_entry *s_entry;
-	struct stat    *statbuf,
-	               *lstatbuf;
-	int             deep_opt;
-
-#endif
 {
 	int             flagpos,
 	                flagval;
@@ -674,11 +653,7 @@ generate_rock_ridge_attributes(whole_name, name,
  * Guaranteed to  return a single sector with the relevant info
  */
 char *
-generate_rr_extension_record(id, descriptor, source, size)
-	char	*id;
-	char	*descriptor;
-	char	*source;
-	int	*size;
+generate_rr_extension_record(char *id, char *descriptor, char *source, int *size)
 {
 	int             lipnt = 0;
 	char           *pnt;
