@@ -118,8 +118,7 @@ struct stat	root_statbuf;		/* Stat buffer for root directory */
 struct directory *reloc_dir;
 
 static char *
-filetype(t)
-	int	t;
+filetype(int t)
 {
 	static	char	unkn[32];
 
@@ -169,9 +168,7 @@ filetype(t)
  * Check if s1 ends in strings s2
  */
 static char *
-rstr(s1, s2)
-	char	*s1;
-	char	*s2;
+rstr(char *s1, char *s2)
 {
 	int	l1;
 	int	l2;
@@ -187,8 +184,7 @@ rstr(s1, s2)
 }
 
 static void
-stat_fix(st)
-	struct stat	*st;
+stat_fix(struct stat *st)
 {
 	int adjust_modes = 0;
 
@@ -236,9 +232,7 @@ stat_fix(st)
 }
 
 int
-stat_filter(path, st)
-	char		*path;
-	struct stat	*st;
+stat_filter(char *path, struct stat *st)
 {
 	int	result = stat(path, st);
 
@@ -248,9 +242,7 @@ stat_filter(path, st)
 }
 
 int
-lstat_filter(path, st)
-	char		*path;
-	struct stat	*st;
+lstat_filter(char *path, struct stat *st)
 {
 	int	result = lstat(path, st);
 
@@ -260,8 +252,7 @@ lstat_filter(path, st)
 }
 
 static int
-sort_n_finish(this_dir)
-	struct directory	*this_dir;
+sort_n_finish(struct directory *this_dir)
 {
 	struct directory_entry *s_entry;
 	struct directory_entry *s_entry1;
@@ -833,7 +824,7 @@ generate_reloc_directory()
 		fstatbuf.st_mode = 0555 | S_IFDIR;
 		fstatbuf.st_nlink = 2;
 		generate_rock_ridge_attributes("",
-			hide_rr_moved ? ".rr_moved" : "rr_moved",
+			(char*)(hide_rr_moved ? ".rr_moved" : "rr_moved"),
 			s_entry, &fstatbuf, &fstatbuf, 0);
 	};
 
@@ -851,9 +842,7 @@ generate_reloc_directory()
  *			we are creating.
  */
 static void
-attach_dot_entries(dirnode, parent_stat)
-	struct directory	*dirnode;
-	struct stat		*parent_stat;
+attach_dot_entries(struct directory *dirnode, struct stat *parent_stat)
 {
 	struct directory_entry *s_entry;
 	struct directory_entry *orig_contents;
@@ -931,9 +920,7 @@ attach_dot_entries(dirnode, parent_stat)
 }
 
 static void
-update_nlink(s_entry, value)
-	struct directory_entry	*s_entry;
-	int			value;
+update_nlink(struct directory_entry *s_entry, int value)
 {
 	unsigned char	*pnt;
 	int		len;
@@ -952,8 +939,7 @@ update_nlink(s_entry, value)
 }
 
 static void
-increment_nlink(s_entry)
-	struct directory_entry	*s_entry;
+increment_nlink(struct directory_entry *s_entry)
 {
 	unsigned char	*pnt;
 	int		len,
@@ -974,10 +960,7 @@ increment_nlink(s_entry)
 }
 
 char *
-find_rr_attribute(pnt, len, attr_type)
-	unsigned char	*pnt;
-	int		len;
-	char		*attr_type;
+find_rr_attribute(unsigned char *pnt, int len, char *attr_type)
 {
 	pnt = parse_xa(pnt, &len, 0);
 	while (len >= 4) {
@@ -1100,10 +1083,7 @@ finish_cl_pl_entries()
  * Notes:
  */
 int
-scan_directory_tree(this_dir, path, de)
-	struct directory	*this_dir;
-	char			*path;
-	struct directory_entry	*de;
+scan_directory_tree(struct directory *this_dir, char *path, struct directory_entry *de)
 {
 	DIR		*current_dir;
 	char		whole_path[PATH_MAX];
@@ -1341,17 +1321,10 @@ scan_directory_tree(this_dir, path, de)
  */
 #ifdef APPLE_HYB
 int
-insert_file_entry(this_dir, whole_path, short_name, have_rsrc)
-	struct directory	*this_dir;
-	char			*whole_path;
-	char			*short_name;
-	int			have_rsrc;
+insert_file_entry(struct directory *this_dir, char *whole_path, char *short_name, int have_rsrc)
 #else
 int
-insert_file_entry(this_dir, whole_path, short_name)
-	struct directory	*this_dir;
-	char			*whole_path;
-	char			*short_name;
+insert_file_entry(struct directory *this_dir, char *whole_path, char *short_name)
 #endif	/* APPLE_HYB */
 {
 	struct stat	statbuf,
@@ -2171,9 +2144,7 @@ insert_file_entry(this_dir, whole_path, short_name)
 
 
 void
-generate_iso9660_directories(node, outfile)
-	struct directory	*node;
-	FILE			*outfile;
+generate_iso9660_directories(struct directory *node, FILE *outfile)
 {
 	struct directory *dpnt;
 
@@ -2197,11 +2168,7 @@ generate_iso9660_directories(node, outfile)
  * Arguments:	parent & de are never NULL at the same time.
  */
 struct directory *
-find_or_create_directory(parent, path, de, flag)
-	struct directory	*parent;
-	const char		*path;
-	struct directory_entry	*de;
-	int			flag;
+find_or_create_directory(struct directory *parent, const char *path, struct directory_entry *de, int flag)
 {
 	struct directory *dpnt;
 	struct directory_entry *orig_de;
@@ -2411,9 +2378,7 @@ find_or_create_directory(parent, path, de, flag)
  * Arguments:
  */
 static void
-delete_directory(parent, child)
-	struct directory	*parent;
-	struct directory	*child;
+delete_directory(struct directory *parent, struct directory *child)
 {
 	struct directory *tdir;
 
@@ -2462,8 +2427,7 @@ delete_directory(parent, child)
 }
 
 int
-sort_tree(node)
-	struct directory	*node;
+sort_tree(struct directory *node)
 {
 	struct directory *dpnt;
 	int		ret = 0;
@@ -2483,8 +2447,7 @@ sort_tree(node)
 }
 
 void
-dump_tree(node)
-	struct directory *node;
+dump_tree(struct directory *node)
 {
 	struct directory *dpnt;
 
@@ -2500,8 +2463,7 @@ dump_tree(node)
 }
 
 void
-update_nlink_field(node)
-	struct directory *node;
+update_nlink_field(struct directory *node)
 {
 	struct directory *dpnt;
 	struct directory *xpnt;
@@ -2558,9 +2520,7 @@ update_nlink_field(node)
  * directory entry for the desired file
  */
 struct directory_entry *
-search_tree_file(node, filename)
-	struct directory *node;
-	char		*filename;
+search_tree_file(struct directory *node, char *filename)
 {
 	struct directory_entry *depnt;
 	struct directory *dpnt;
