@@ -109,7 +109,6 @@ static	void	free_directories __PR((struct directory *dpnt));
 static	void	build_pathlist	__PR((struct directory *node));
 static	int	compare_paths	__PR((void const *r, void const *l));
 static	int	generate_path_tables __PR((void));
-	void	memcpy_max	__PR((char *to, char *from, int max));
 	void	outputlist_insert __PR((struct output_fragment *frag));
 static	int	file_write	__PR((FILE *outfile));
 static	int	pvd_write	__PR((FILE *outfile));
@@ -223,11 +222,7 @@ unsigned int get_733(char *p)
 }
 
 void
-xfwrite(buffer, count, size, file)
-	void	*buffer;
-	int	count;
-	int	size;
-	FILE	*file;
+xfwrite(void *buffer, int count, int size, FILE *file)
 {
 	/*
 	 * This is a hack that could be made better.
@@ -293,8 +288,7 @@ static time_t	begun;
  * goes in front of them
  */
 static int
-assign_directory_addresses(node)
-	struct directory	*node;
+assign_directory_addresses(struct directory *node)
 {
 	int		dir_size;
 	struct directory *dpnt;
@@ -424,8 +418,7 @@ static	char		buffer[SECTOR_SIZE * NSECT];
 }/* write_one_file(... */
 
 static void
-write_files(outfile)
-	FILE	*outfile;
+write_files(FILE *outfile)
 {
 	struct deferred_write	*dwpnt,
 				*dwnext;
@@ -513,9 +506,7 @@ dump_filelist()
 #endif
 
 static int
-compare_dirs(rr, ll)
-	const void	*rr;
-	const void	*ll;
+compare_dirs(const void *rr, const void *ll)
 {
 	char		*rpnt,
 			*lpnt;
@@ -648,9 +639,7 @@ compare_dirs(rr, ll)
  * Notes:		Returns 0 if OK, returns > 0 if an error occurred.
  */
 int
-sort_directory(sort_dir, rr)
-	struct directory_entry **sort_dir;
-	int		rr;
+sort_directory(struct directory_entry **sort_dir, int rr)
 {
 	int		dcount = 0;
 	int		xcount = 0;
@@ -696,10 +685,10 @@ sort_directory(sort_dir, rr)
 	if (dcount < 2) {
 #ifdef	USE_LIBSCHILY
 		errmsgno(EX_BAD,
-			"Directory size too small (. or .. missing ???)\n");
+			"Directory size too small (. or .. missing ??\077)\n");
 #else
 		fprintf(stderr,
-			"Directory size too small (. or .. missing ???)\n");
+			"Directory size too small (. or .. missing ??\077)\n");
 #endif
 		sort_goof = 1;
 
@@ -757,9 +746,7 @@ root_gen()
  *	sorts deferred_write entries based on the sort weight
  */
 static int
-compare_sort(rr, ll)
-	const void	*rr;
-	const void	*ll;
+compare_sort(const void *rr, const void *ll)
 {
 	struct deferred_write	**r;
 	struct deferred_write	**l;
@@ -782,8 +769,7 @@ compare_sort(rr, ll)
  *	files that may have been sorted
  */
 static void
-reassign_link_addresses(dpnt)
-	struct directory	*dpnt;
+reassign_link_addresses(struct directory *dpnt)
 {
 	struct directory_entry	*s_entry;
 	struct file_hash	*s_hash;
@@ -894,8 +880,7 @@ sort_file_addresses()
 
 
 static void
-assign_file_addresses(dpnt)
-	struct directory	*dpnt;
+assign_file_addresses(struct directory *dpnt)
 {
 	struct directory *finddir;
 	struct directory_entry *s_entry;
@@ -1190,8 +1175,7 @@ assign_file_addresses(dpnt)
 }/* assign_file_addresses(... */
 
 static void
-free_one_directory(dpnt)
-	struct directory	*dpnt;
+free_one_directory(struct directory *dpnt)
 {
 	struct directory_entry *s_entry;
 	struct directory_entry *s_entry_d;
@@ -1225,8 +1209,7 @@ free_one_directory(dpnt)
 }/* free_one_directory(... */
 
 static void
-free_directories(dpnt)
-	struct directory	*dpnt;
+free_directories(struct directory *dpnt)
 {
 	while (dpnt) {
 		free_one_directory(dpnt);
@@ -1237,9 +1220,7 @@ free_directories(dpnt)
 }
 
 void
-generate_one_directory(dpnt, outfile)
-	struct directory	*dpnt;
-	FILE			*outfile;
+generate_one_directory(struct directory *dpnt, FILE *outfile)
 {
 	unsigned int	ce_address = 0;
 	char		*ce_buffer;
@@ -1412,8 +1393,7 @@ generate_one_directory(dpnt, outfile)
 }/* generate_one_directory(... */
 
 static void
-build_pathlist(node)
-	struct directory	*node;
+build_pathlist(struct directory *node)
 {
 	struct directory *dpnt;
 
@@ -1431,9 +1411,7 @@ build_pathlist(node)
 }/* build_pathlist(... */
 
 static int
-compare_paths(r, l)
-	void const	*r;
-	void const	*l;
+compare_paths(void const *r, void const *l)
 {
 	struct directory const *ll = *(struct directory * const *) l;
 	struct directory const *rr = *(struct directory * const *) r;
@@ -1587,28 +1565,12 @@ generate_path_tables()
 }/* generate_path_tables(... */
 
 void
-memcpy_max(to, from, max)
-	char	*to;
-	char	*from;
-	int	max;
-{
-	int	n = strlen(from);
-
-	if (n > max) {
-		n = max;
-	}
-	memcpy(to, from, n);
-
-}/* memcpy_max(... */
-
-void
-outputlist_insert(frag)
-	struct output_fragment *frag;
+outputlist_insert(struct output_fragment *frag)
 {
 	struct output_fragment *nfrag;
 
-	nfrag = e_malloc(sizeof(*frag));
-	movebytes(frag, nfrag, sizeof(*frag));
+	nfrag = (struct output_fragment*)e_malloc(sizeof(*frag));
+	memmove(nfrag, frag, sizeof(*frag));
 	nfrag->of_start_extent = 0;
 
 	if (out_tail == NULL) {
@@ -1620,8 +1582,7 @@ outputlist_insert(frag)
 }
 
 static int
-file_write(outfile)
-	FILE	*outfile;
+file_write(FILE *outfile)
 {
 	Uint	should_write;
 
@@ -1741,8 +1702,7 @@ file_write(outfile)
  * Function to write the PVD for the disc.
  */
 static int
-pvd_write(outfile)
-	FILE	*outfile;
+pvd_write(FILE *outfile)
 {
 	char		iso_time[17];
 	int		should_write;
@@ -1777,10 +1737,10 @@ pvd_write(outfile)
 	vol_desc.version[0] = 1;
 
 	memset(vol_desc.system_id, ' ', sizeof(vol_desc.system_id));
-	memcpy_max(vol_desc.system_id, system_id, strlen(system_id));
+	strncpy(vol_desc.system_id, system_id, strlen(system_id));
 
 	memset(vol_desc.volume_id, ' ', sizeof(vol_desc.volume_id));
-	memcpy_max(vol_desc.volume_id, volume_id, strlen(volume_id));
+	strncpy(vol_desc.volume_id, volume_id, strlen(volume_id));
 
 	should_write = last_extent - session_start;
 	set_733((char *) vol_desc.volume_space_size, should_write);
@@ -1808,33 +1768,33 @@ pvd_write(outfile)
 	 */
 	FILL_SPACE(volume_set_id);
 	if (volset_id)
-		memcpy_max(vol_desc.volume_set_id, volset_id, strlen(volset_id));
+		strncpy(vol_desc.volume_set_id, volset_id, strlen(volset_id));
 
 	FILL_SPACE(publisher_id);
 	if (publisher)
-		memcpy_max(vol_desc.publisher_id, publisher, strlen(publisher));
+		strncpy(vol_desc.publisher_id, publisher, strlen(publisher));
 
 	FILL_SPACE(preparer_id);
 	if (preparer)
-		memcpy_max(vol_desc.preparer_id, preparer, strlen(preparer));
+		strncpy(vol_desc.preparer_id, preparer, strlen(preparer));
 
 	FILL_SPACE(application_id);
 	if (appid)
-		memcpy_max(vol_desc.application_id, appid, strlen(appid));
+		strncpy(vol_desc.application_id, appid, strlen(appid));
 
 	FILL_SPACE(copyright_file_id);
 	if (copyright)
-		memcpy_max(vol_desc.copyright_file_id, copyright,
+		strncpy(vol_desc.copyright_file_id, copyright,
 			strlen(copyright));
 
 	FILL_SPACE(abstract_file_id);
 	if (abstract)
-		memcpy_max(vol_desc.abstract_file_id, abstract,
+		strncpy(vol_desc.abstract_file_id, abstract,
 			strlen(abstract));
 
 	FILL_SPACE(bibliographic_file_id);
 	if (biblio)
-		memcpy_max(vol_desc.bibliographic_file_id, biblio,
+		strncpy(vol_desc.bibliographic_file_id, biblio,
 			strlen(biblio));
 
 	FILL_SPACE(creation_date);
@@ -1859,8 +1819,7 @@ pvd_write(outfile)
  * Function to write the EVD for the disc.
  */
 static int
-evd_write(outfile)
-	FILE	*outfile;
+evd_write(FILE *outfile)
 {
 	struct iso_primary_descriptor evol_desc;
 
@@ -1881,8 +1840,7 @@ evd_write(outfile)
  * Function to write the version information for the disc.
  */
 static int
-vers_write(outfile)
-	FILE	*outfile;
+vers_write(FILE *outfile)
 {
 	char		vers[SECTOR_SIZE+1];
 	int		X_ac;
@@ -1934,10 +1892,7 @@ vers_write(outfile)
  * Avoid to write unwanted information into the version info string.
  */
 LOCAL int
-graftcp(to, from, ep)
-	char	*to;
-	char	*from;
-	char	*ep;
+graftcp(char *to, char *from, char *ep)
 {
 	int	len = strlen(from);
 	char	*node = NULL;
@@ -1960,10 +1915,7 @@ graftcp(to, from, ep)
 }
 
 LOCAL int
-pathcp(to, from, ep)
-	char	*to;
-	char	*from;
-	char	*ep;
+pathcp(char *to, char *from, char *ep)
 {
 	int	len = strlen(from);
 	char	*p;
@@ -1996,8 +1948,7 @@ pathcp(to, from, ep)
  * Function to write the path table for the disc.
  */
 static int
-pathtab_write(outfile)
-	FILE	*outfile;
+pathtab_write(FILE *outfile)
 {
 	/* Next we write the path tables */
 	xfwrite(path_table_l, 1, path_blocks << 11, outfile);
@@ -2011,8 +1962,7 @@ pathtab_write(outfile)
 }
 
 static int
-exten_write(outfile)
-	FILE	*outfile;
+exten_write(FILE *outfile)
 {
 	xfwrite(extension_record, 1, SECTOR_SIZE, outfile);
 	last_extent_written++;
@@ -2023,8 +1973,7 @@ exten_write(outfile)
  * Functions to describe padding block at the start of the disc.
  */
 int
-oneblock_size(starting_extent)
-	int	starting_extent;
+oneblock_size(int starting_extent)
 {
 	last_extent++;
 	return 0;
@@ -2034,8 +1983,7 @@ oneblock_size(starting_extent)
  * Functions to describe path table size.
  */
 static int
-pathtab_size(starting_extent)
-	int	starting_extent;
+pathtab_size(int starting_extent)
 {
 	path_table[0] = starting_extent;
 
@@ -2050,8 +1998,7 @@ pathtab_size(starting_extent)
  * Functions to describe padding blocks before PVD.
  */
 static int
-padblock_size(starting_extent)
-	int	starting_extent;
+padblock_size(int starting_extent)
 {
 	last_extent = session_start + 16;
 	return 0;
@@ -2061,8 +2008,7 @@ padblock_size(starting_extent)
  * Functions to describe padding blocks at end of disk.
  */
 static int
-padend_size(starting_extent)
-	int	starting_extent;
+padend_size(int starting_extent)
 {
 	int	emod = 0;
 
@@ -2118,8 +2064,7 @@ dirtree_dump()
 }
 
 static int
-dirtree_fixup(starting_extent)
-	int	starting_extent;
+dirtree_fixup(int starting_extent)
 {
 	if (use_RockRidge && reloc_dir)
 		finish_cl_pl_entries();
@@ -2130,16 +2075,14 @@ dirtree_fixup(starting_extent)
 }
 
 static int
-dirtree_size(starting_extent)
-	int	starting_extent;
+dirtree_size(int starting_extent)
 {
 	assign_directory_addresses(root);
 	return 0;
 }
 
 static int
-ext_size(starting_extent)
-	int	starting_extent;
+ext_size(int starting_extent)
 {
 	extern int		extension_record_size;
 	struct directory_entry *s_entry;
@@ -2155,24 +2098,21 @@ ext_size(starting_extent)
 }
 
 static int
-dirtree_write(outfile)
-	FILE	*outfile;
+dirtree_write(FILE *outfile)
 {
 	generate_iso9660_directories(root, outfile);
 	return 0;
 }
 
 static int
-dirtree_cleanup(outfile)
-	FILE	*outfile;
+dirtree_cleanup(FILE *outfile)
 {
 	free_directories(root);
 	return 0;
 }
 
 static int
-padblock_write(outfile)
-	FILE	*outfile;
+padblock_write(FILE *outfile)
 {
 	char	buffer[SECTOR_SIZE];
 	int	i;
@@ -2191,8 +2131,7 @@ padblock_write(outfile)
 }
 
 static int
-padend_write(outfile)
-	FILE	*outfile;
+padend_write(FILE *outfile)
 {
 	char	buffer[SECTOR_SIZE];
 	int	i;
@@ -2219,8 +2158,7 @@ padend_write(outfile)
  */
 
 static int
-hfs_get_parms(key)
-	char	*key;
+hfs_get_parms(char *key)
 {
 	int	ret = 0;
 	char	*p;
@@ -2240,8 +2178,7 @@ hfs_get_parms(key)
  *	hfs_file_gen:	set up "fake" HFS volume using the ISO9660 tree
  */
 static void
-hfs_file_gen(start_extent)
-	int	start_extent;
+hfs_file_gen(int start_extent)
 {
 	int	Csize;	/* clump size for HFS vol */
 	int	loop;
@@ -2410,8 +2347,7 @@ gen_prepboot()
  *			allocation block size for each file
  */
 Ulong
-get_adj_size(Csize)
-	int	Csize;
+get_adj_size(int Csize)
 {
 	struct deferred_write *dw;
 	Ulong		size = 0;
@@ -2440,10 +2376,7 @@ get_adj_size(Csize)
  *			based on the HFS allocation block size
  */
 int
-adj_size(Csize, start_extent, extra)
-	int	Csize;
-	int	start_extent;
-	int	extra;
+adj_size(int Csize, int start_extent, int extra)
 {
 	struct deferred_write *dw;
 	struct directory_entry *s_entry;
@@ -2495,8 +2428,7 @@ adj_size(Csize, start_extent, extra)
  *			entry of it's own
  */
 void
-adj_size_other(dpnt)
-	struct directory	*dpnt;
+adj_size_other(struct directory *dpnt)
 {
 	struct directory_entry *s_entry;
 	struct file_hash *s_hash;
@@ -2540,8 +2472,7 @@ adj_size_other(dpnt)
  *	hfs_hce_write:	write out the HFS header stuff
  */
 static int
-hfs_hce_write(outfile)
-	FILE	*outfile;
+hfs_hce_write(FILE *outfile)
 {
 	char	buffer[SECTOR_SIZE];
 	int	n = 0;
@@ -2579,8 +2510,7 @@ hfs_hce_write(outfile)
  *				800k
  */
 int
-insert_padding_file(size)
-	int	size;
+insert_padding_file(int size)
 {
 	struct deferred_write *dwpnt;
 
@@ -2610,7 +2540,7 @@ insert_padding_file(size)
 	}
 
 	/* aloocate memory as a "Table" file */
-	dwpnt->table = e_malloc(size);
+	dwpnt->table = (char*)e_malloc(size);
 	dwpnt->name = NULL;
 
 	dwpnt->next = NULL;
