@@ -48,8 +48,7 @@ extern	BOOL	getint		__PR((char *, int *, int, int));
 extern	BOOL	yes		__PR((char *, ...));
 
 LOCAL
-char *skipwhite(s)
-		 const char	*s;
+char *skipwhite(const char *s)
 {
 	register const Uchar	*p = (const Uchar *)s;
 
@@ -64,12 +63,7 @@ char *skipwhite(s)
 /* ARGSUSED */
 EXPORT
 BOOL
-cvt_std(linep, lp, mini, maxi, dp)
-	char	*linep;
-	long	*lp;
-	long	mini;
-	long	maxi;
-	struct disk	*dp;
+cvt_std(char *linep, long *lp, long mini, long maxi, struct disk *dp)
 {
 	long	l	= -1L;
 
@@ -111,25 +105,13 @@ cvt_std(linep, lp, mini, maxi, dp)
 
 /* ARGSUSED */
 LOCAL void
-prt_std(s, l, mini, maxi, dp)
-	char	*s;
-	long	l;
-	long	mini;
-	long	maxi;
-	struct disk *dp;
+prt_std(char *s, long l, long mini, long maxi, struct disk *dp)
 {
 	printf("%s %ld (%ld - %ld)/<cr>:", s, l, mini, maxi);
 }
 
 EXPORT
-BOOL getvalue(s, lp, mini, maxi, prt, cvt, dp)
-	char	*s;
-	long	*lp;
-	long	mini;
-	long	maxi;
-	void	(*prt) __PR((char *, long, long, long, struct disk *));
-	BOOL	(*cvt) __PR((char *, long *, long, long, struct disk *));
-	struct disk	*dp;
+BOOL getvalue(char *s, long *lp, long mini, long maxi, void (*prt)(char*,long,long,long,struct disk*), BOOL (*cvt)(char*,long*,long,long,struct disk*), struct disk *dp)
 {
 	char	line[128];
 	char	*linep;
@@ -159,21 +141,13 @@ BOOL getvalue(s, lp, mini, maxi, prt, cvt, dp)
 }
 
 EXPORT
-BOOL getlong(s, lp, mini, maxi)
-	char	*s;
-	long	*lp;
-	long	mini;
-	long	maxi;
+BOOL getlong(char *s, long *lp, long mini, long maxi)
 {
-	return (getvalue(s, lp, mini, maxi, prt_std, cvt_std, (void *)0));
+	return (getvalue(s, lp, mini, maxi, prt_std, cvt_std, (struct disk *)0));
 }
 
 EXPORT
-BOOL getint(s, ip, mini, maxi)
-	char	*s;
-	int	*ip;
-	int	mini;
-	int	maxi;
+BOOL getint(char *s, int *ip, int mini, int maxi)
 {
 	long	l = *ip;
 	BOOL	ret;
@@ -184,14 +158,7 @@ BOOL getint(s, ip, mini, maxi)
 }
 
 /* VARARGS1 */
-#ifdef	PROTOTYPES
 EXPORT BOOL yes(char *form, ...)
-#else
-EXPORT
-BOOL yes(form, va_alist)
-	char	*form;
-	va_dcl
-#endif
 {
 	va_list	args;
 	char okbuf[10];
