@@ -23,7 +23,6 @@ static	char sccsid[] =
  * along with this program; see the file COPYING.  If not, write to
  * the Free Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-
 #include <mconfig.h>
 #include <stdio.h>
 #include <standard.h>
@@ -176,8 +175,7 @@ struct	scsi_format_data fmt;
 /*XXX*/EXPORT	void print_defect_list(){}
 
 LOCAL void
-usage(ret)
-	int	ret;
+usage(int ret)
 {
 	error("Usage:\treadcd [options]\n");
 	error("options:\n");
@@ -205,9 +203,7 @@ usage(ret)
 char	opts[]   = "debug#,d+,kdebug#,kd#,timeout#,quiet,q,verbose+,v+,Verbose+,V+,x+,xd#,silent,s,help,h,version,dev*,sectors*,w,c2scan,fulltoc,clone,noerror,nocorr,notrunc,retries#,f*";
 
 EXPORT int
-main(ac, av)
-	int	ac;
-	char	*av[];
+main(int ac, char **av)
 {
 	char	*dev = NULL;
 	int	fcount;
@@ -328,7 +324,7 @@ main(ac, av)
 	scg_settimeout(scgp, deftimeout);
 
 	Sbufsize = scg_bufsize(scgp, 256*1024L);
-	if ((Sbuf = scg_getbuf(scgp, Sbufsize)) == NULL)
+	if ((Sbuf = (char*)scg_getbuf(scgp, Sbufsize)) == NULL)
 		comerr("Cannot get SCSI I/O buffer.\n");
 
 	is_suid = geteuid() != getuid();
@@ -393,8 +389,7 @@ main(ac, av)
  * XXX Eine Loesung waere ein Abort Callback in SCSI *.
  */
 LOCAL void
-intr(sig)
-	int	sig;
+intr(int sig)
 {
 	didintr++;
 	exsig = sig;
@@ -403,9 +398,7 @@ intr(sig)
 
 /* ARGSUSED */
 LOCAL void
-exscsi(excode, arg)
-	int	excode;
-	void	*arg;
+exscsi(int excode, void *arg)
 {
 	struct exargs	*exp = (struct exargs *)arg;
 		int	i;
@@ -436,9 +429,7 @@ exscsi(excode, arg)
 }
 
 LOCAL void
-excdr(excode, arg)
-	int	excode;
-	void	*arg;
+excdr(int excode, void *arg)
 {
 	exscsi(excode, arg);
 
@@ -476,10 +467,7 @@ prstats()
 }
 
 LOCAL void
-dorw(scgp, filename, sectors)
-	SCSI	*scgp;
-	char	*filename;
-	char	*sectors;
+dorw(SCSI *scgp, char *filename, char *sectors)
 {
 	parm_t	params;
 	char	*p = NULL;
@@ -513,8 +501,7 @@ dorw(scgp, filename, sectors)
 }
 
 LOCAL void
-doit(scgp)
-	SCSI	*scgp;
+doit(SCSI *scgp)
 {
 	int	i = 0;
 	parm_t	params;
@@ -546,9 +533,7 @@ doit(scgp)
 }
 
 LOCAL void
-read_disk(scgp, parmp)
-	SCSI	*scgp;
-	parm_t	*parmp;
+read_disk(SCSI *scgp, parm_t *parmp)
 {
 	rparm_t	rp;
 
@@ -569,9 +554,7 @@ read_disk(scgp, parmp)
 char	zeroblk[512];
 
 LOCAL void
-readc2_disk(scgp, parmp)
-	SCSI	*scgp;
-	parm_t	*parmp;
+readc2_disk(SCSI *scgp, parm_t *parmp)
 {
 	rparm_t	rp;
 	int	osecsize = 2048;
@@ -615,20 +598,14 @@ readc2_disk(scgp, parmp)
 
 /* ARGSUSED */
 LOCAL int
-fread_data(scgp, rp, bp, addr, cnt)
-	SCSI	*scgp;
-	rparm_t	*rp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
+fread_data(SCSI *scgp, rparm_t *rp, caddr_t bp, long addr, int cnt)
 {
 	return (read_g1(scgp, bp, addr, cnt));
 }
 
 
 LOCAL int
-bits(c)
-	int	c;
+bits(int c)
 {
 	int	n = 0;
 
@@ -652,8 +629,7 @@ bits(c)
 }
 
 LOCAL int 
-bitidx(c)
-	int	c;
+bitidx(int c)
 {
 	if (c & 0x80)
 		return (0);
@@ -675,12 +651,7 @@ bitidx(c)
 }
 
 LOCAL int
-fread_c2(scgp, rp, bp, addr, cnt)
-	SCSI	*scgp;
-	rparm_t	*rp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
+fread_c2(SCSI *scgp, rparm_t *rp, caddr_t bp, long addr, int cnt)
 {
 	if (rp->ismmc) {
 		return (read_cd(scgp, bp, addr, cnt, rp->secsize,
@@ -698,21 +669,13 @@ fread_c2(scgp, rp, bp, addr, cnt)
 
 /* ARGSUSED */
 LOCAL int
-fdata_null(rp, bp, addr, cnt)
-	rparm_t	*rp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
+fdata_null(rparm_t *rp, caddr_t bp, long addr, int cnt)
 {
 	return (0);
 }
 
 LOCAL int
-fdata_c2(rp, bp, addr, cnt)
-	rparm_t	*rp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
+fdata_c2(rparm_t *rp, caddr_t bp, long addr, int cnt)
 {
 	int	i;
 	int	j;
@@ -743,15 +706,11 @@ fdata_c2(rp, bp, addr, cnt)
 
 #ifdef	used
 LOCAL int
-read_scsi_g1(scgp, bp, addr, cnt)
-	SCSI	*scgp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
+read_scsi_g1(SCSI *scgp, caddr_t bp, long addr, int cnt)
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
 	scmd->addr = bp;
 /*	scmd->size = cnt*512;*/
 	scmd->size = cnt*scgp->cap->c_bsize;
@@ -772,11 +731,7 @@ read_scsi_g1(scgp, bp, addr, cnt)
 #define	G0_MAXADDR	0x1FFFFFL
 
 EXPORT int
-write_scsi(scgp, bp, addr, cnt)
-	SCSI	*scgp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
+write_scsi(SCSI *scgp, caddr_t bp, long addr, int cnt)
 {
 	if(addr <= G0_MAXADDR)
 		return(write_g0(scgp, bp, addr, cnt));
@@ -785,18 +740,14 @@ write_scsi(scgp, bp, addr, cnt)
 }
 
 EXPORT int
-write_g0(scgp, bp, addr, cnt)
-	SCSI	*scgp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
+write_g0(SCSI *scgp, caddr_t bp, long addr, int cnt)
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
 	if (scgp->cap->c_bsize <= 0)
 		raisecond("capacity_not_set", 0L);
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
 	scmd->addr = bp;
 	scmd->size = cnt*scgp->cap->c_bsize;
 	scmd->flags = SCG_DISRE_ENA;
@@ -813,18 +764,14 @@ write_g0(scgp, bp, addr, cnt)
 }
 
 EXPORT int
-write_g1(scgp, bp, addr, cnt)
-	SCSI	*scgp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
+write_g1(SCSI *scgp, caddr_t bp, long addr, int cnt)
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
 	if (scgp->cap->c_bsize <= 0)
 		raisecond("capacity_not_set", 0L);
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
 	scmd->addr = bp;
 	scmd->size = cnt*scgp->cap->c_bsize;
 	scmd->flags = SCG_DISRE_ENA;
@@ -842,8 +789,7 @@ write_g1(scgp, bp, addr, cnt)
 
 #ifdef	used
 LOCAL void
-Xrequest_sense(scgp)
-	SCSI	*scgp;
+Xrequest_sense(SCSI *scgp)
 {
 	char	sense_buf[32];
 	struct	scg_cmd ocmd;
@@ -853,11 +799,11 @@ Xrequest_sense(scgp)
 
 	cmdsave = scgp->cmdname;
 
-	movebytes(scmd, &ocmd, sizeof(*scmd));
+	memcpy(&ocmd, scmd, sizeof(*scmd));
 
-	fillbytes((caddr_t)sense_buf, sizeof(sense_buf), '\0');
+	memset((caddr_t)sense_buf, 0, sizeof(sense_buf));
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
 	scmd->addr = (caddr_t)sense_buf;
 	scmd->size = sizeof(sense_buf);
 	scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -872,9 +818,9 @@ Xrequest_sense(scgp)
 	scg_cmd(scgp);
 
 	sense_count = sizeof(sense_buf) - scg_getresid(scgp);
-	movebytes(&ocmd, scmd, sizeof(*scmd));
+	memcpy(scmd, &ocmd, sizeof(*scmd));
 	scmd->sense_count = sense_count;
-	movebytes(sense_buf, (Uchar *)&scmd->sense, scmd->sense_count);
+	memcpy((Uchar *)&scmd->sense, sense_buf, scmd->sense_count);
 
 	scgp->cmdname = cmdsave;
 	scg_printerr(scgp);
@@ -883,17 +829,11 @@ Xrequest_sense(scgp)
 #endif
 
 LOCAL int
-read_retry(scgp, bp, addr, cnt, rfunc, rp)
-	SCSI	*scgp;
-	caddr_t	bp;
-	long	addr;
-	long	cnt;
-	int	(*rfunc)__PR((SCSI *scgp, rparm_t *rp, caddr_t bp, long addr, int cnt));
-	rparm_t	*rp;
+read_retry(SCSI *scgp, caddr_t bp, long addr, long cnt, int (*rfunc)(SCSI *scgp, rparm_t *rp, caddr_t bp, long addr, int cnt), rparm_t *rp)
 {
 /*	int	secsize = scgp->cap->c_bsize;*/
 	int	secsize = rp->secsize;
-	int	try = 0;
+	int	ntry = 0;
 	int	err;
 	char	dummybuf[8192];
 
@@ -910,13 +850,13 @@ read_retry(scgp, bp, addr, cnt, rfunc, rp)
 			if (didintr)
 				comexit(exsig);		/* XXX besseres Konzept?!*/
 			wait_unit_ready(scgp, 120);
-			if (try >= 10) {		/* First 10 retries without seek */
-				if ((try % 8) == 0) {
+			if (ntry >= 10) {		/* First 10 retries without seek */
+				if ((ntry % 8) == 0) {
 					error("+");	/* Read last sector */
 					scgp->silent++;
 					(*rfunc)(scgp, rp, dummybuf, scgp->cap->c_baddr, 1);
 					scgp->silent--;
-				} else if ((try % 4) == 0) {
+				} else if ((ntry % 4) == 0) {
 					error("-");	/* Read first sector */
 					scgp->silent++;
 					(*rfunc)(scgp, rp, dummybuf, 0, 1);
@@ -934,7 +874,7 @@ read_retry(scgp, bp, addr, cnt, rfunc, rp)
 			if (didintr)
 				comexit(exsig);		/* XXX besseres Konzept?!*/
 
-			fillbytes(bp, secsize, 0);
+			memset(bp, 0, secsize);
 
 			scgp->silent++;
 			err = (*rfunc)(scgp, rp, bp, addr, 1);
@@ -947,9 +887,9 @@ read_retry(scgp, bp, addr, cnt, rfunc, rp)
 			} else {
 				break;
 			}
-		} while (++try < retries);
+		} while (++ntry < retries);
 
-		if (try >= retries) {
+		if (ntry >= retries) {
 			error("\n");
 			errmsgno(err, "Error on sector %ld not corrected. Total of %d errors.\n",
 					addr, ++rp->errors);
@@ -961,14 +901,14 @@ read_retry(scgp, bp, addr, cnt, rfunc, rp)
 				return (-1);
 			errmsgno(EX_BAD, "-noerror set, continuing ...\n");
 		} else {
-			if (try > 1) {
+			if (ntry > 1) {
 				error("\n");
 				errmsgno(EX_BAD,
 				"Error on sector %ld corrected after %d tries. Total of %d errors.\n",
-					addr, try, rp->errors);
+					addr, ntry, rp->errors);
 			}
 		}
-		try = 0;
+		ntry = 0;
 		cnt -= 1;
 		addr += 1;
 		bp += secsize;
@@ -977,12 +917,7 @@ read_retry(scgp, bp, addr, cnt, rfunc, rp)
 }
 
 LOCAL void
-read_generic(scgp, parmp, rfunc, rp, dfunc)
-	SCSI	*scgp;
-	parm_t	*parmp;
-	int	(*rfunc)__PR((SCSI *scgp, rparm_t *rp, caddr_t bp, long addr, int cnt));
-	rparm_t	*rp;
-	int	(*dfunc)__PR((rparm_t *rp, caddr_t bp, long addr, int cnt));
+read_generic(SCSI *scgp, parm_t *parmp, int (*rfunc)(SCSI *scgp, rparm_t *rp, caddr_t bp, long addr, int cnt), rparm_t *rp, int (*dfunc)(rparm_t *rp, caddr_t bp, long addr, int cnt))
 {
 	char	filename[512];
 	char	*defname = NULL;
@@ -1126,9 +1061,7 @@ out:
 }
 
 LOCAL void
-write_disk(scgp, parmp)
-	SCSI	*scgp;
-	parm_t	*parmp;
+write_disk(SCSI *scgp, parm_t *parmp)
 {
 	char	filename[512];
 	char	*defname = "disk.out";
@@ -1227,8 +1160,7 @@ else {
 }
 
 LOCAL int
-choice(n)
-	int	n;
+choice(int n)
 {
 #if	defined(HAVE_DRAND48)
 	extern	double	drand48 __PR((void));
@@ -1246,8 +1178,7 @@ choice(n)
 }
 
 LOCAL void
-ra(scgp)
-	SCSI	*scgp;
+ra(SCSI *scgp)
 {
 /*	char	filename[512];*/
 	FILE	*f;
@@ -1261,7 +1192,7 @@ ra(scgp)
 	select_secsize(scgp, 2352);
 	read_capacity(scgp);
 	print_capacity(scgp, stderr);
-	fillbytes(Sbuf, 50*2352, 0);
+	memset(Sbuf, 0, 50*2352);
 	if (read_g1(scgp, Sbuf, 0, 50) < 0)
 		errmsg("read CD\n");
 	f = fileopen("DDA", "wctb");
@@ -1275,20 +1206,14 @@ ra(scgp)
 				 (cdb)->count[2] = (len) & 0xFF)
 
 EXPORT int
-read_da(scgp, bp, addr, cnt, framesize, subcode)
-	SCSI	*scgp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
-	int	framesize;
-	int	subcode;
+read_da(SCSI *scgp, caddr_t bp, long addr, int cnt, int framesize, int subcode)
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
 	if (scgp->cap->c_bsize <= 0)
 		raisecond("capacity_not_set", 0L);
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
 	scmd->addr = bp;
 	scmd->size = cnt*framesize;
 	scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -1306,18 +1231,11 @@ read_da(scgp, bp, addr, cnt, framesize, subcode)
 }
 
 EXPORT int
-read_cd(scgp, bp, addr, cnt, framesize, data, subch)
-	SCSI	*scgp;
-	caddr_t	bp;
-	long	addr;
-	int	cnt;
-	int	framesize;
-	int	data;
-	int	subch;
+read_cd(SCSI *scgp, caddr_t bp, long addr, int cnt, int framesize, int data, int subch)
 {
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
-	fillbytes((caddr_t)scmd, sizeof(*scmd), '\0');
+	memset((caddr_t)scmd, 0, sizeof(*scmd));
 	scmd->addr = bp;
 	scmd->size = cnt*framesize;
 	scmd->flags = SCG_RECV_DATA|SCG_DISRE_ENA;
@@ -1338,10 +1256,7 @@ read_cd(scgp, bp, addr, cnt, framesize, data, subch)
 }
 
 LOCAL void
-oldmode(scgp, errp, retrp)
-	SCSI	*scgp;
-	int	*errp;
-	int	*retrp;
+oldmode(SCSI *scgp, int *errp, int *retrp)
 {
 	Uchar	mode[0x100];
 	Uchar	cmode[0x100];
@@ -1349,8 +1264,8 @@ oldmode(scgp, errp, retrp)
 	int	i;
 	int	len;
 
-	fillbytes(mode, sizeof(mode), '\0');
-	fillbytes(cmode, sizeof(cmode), '\0');
+	memset(mode, 0, sizeof(mode));
+	memset(cmode, 0, sizeof(cmode));
 
 	if (!get_mode_params(scgp, 0x01, "CD error recovery parameter",
 			mode, (Uchar *)0, (Uchar *)cmode, (Uchar *)0, &len)) {
@@ -1378,10 +1293,7 @@ oldmode(scgp, errp, retrp)
 }
 
 LOCAL void
-domode(scgp, err, retr)
-	SCSI	*scgp;
-	int	err;
-	int	retr;
+domode(SCSI *scgp, int err, int retr)
 {
 	Uchar	mode[0x100];
 	Uchar	cmode[0x100];
@@ -1389,8 +1301,8 @@ domode(scgp, err, retr)
 	int	i;
 	int	len;
 
-	fillbytes(mode, sizeof(mode), '\0');
-	fillbytes(cmode, sizeof(cmode), '\0');
+	memset(mode, 0, sizeof(mode));
+	memset(cmode, 0, sizeof(cmode));
 
 	if (!get_mode_params(scgp, 0x01, "CD error recovery parameter",
 			mode, (Uchar *)0, (Uchar *)cmode, (Uchar *)0, &len)) {
@@ -1447,10 +1359,7 @@ LOCAL	void	qpto96		__PR((Uchar *sub, Uchar *subq, int dop));
  */
 LOCAL void
 /*EXPORT void*/
-qpto96(sub, subqptr, dop)
-	Uchar	*sub;
-	Uchar	*subqptr;
-	int	dop;
+qpto96(Uchar *sub, Uchar *subqptr, int dop)
 {
 	Uchar	tmp[16];
 	Uchar	*p;
@@ -1458,10 +1367,10 @@ qpto96(sub, subqptr, dop)
 	int	i;
 
 	if (subqptr == sub) {
-		movebytes(subqptr, tmp, 12);
+		memmove(tmp, subqptr, 12);
 		subqptr = tmp;
 	}
-	fillbytes(sub, 96, '\0');
+	memset(sub, 0, 96);
 
 	if (dop) for (i=0, p = sub; i < 96; i++) {
 		*p++ |= 0x80;
